@@ -160,7 +160,7 @@
        (t
 	(aset ret j (or prefix ?=))
 	(setq j (1+ j))
-	(aset ret j (aref "0123456789ABCDEF" (lsh char -4)))
+	(aset ret j (aref "0123456789ABCDEF" (ash char -4)))
 	(setq j (1+ j))
 	(aset ret j (aref "0123456789ABCDEF" (logand char 15)))))
       (setq j (1+ j)))
@@ -182,7 +182,7 @@
 	  (aset ret j char)
 	(aset ret j ?:)
 	(setq j (1+ j))
-	(aset ret j (aref "0123456789abcdef" (lsh char -4)))
+	(aset ret j (aref "0123456789abcdef" (ash char -4)))
 	(setq j (1+ j))
 	(aset ret j (aref "0123456789abcdef" (logand char 15))))
       (setq j (1+ j)))
@@ -847,7 +847,7 @@ That is, each line may be more than 75."
 	  (aset ret j char)
 	(aset ret j ?%)
 	(setq j (1+ j))
-	(aset ret j (aref "0123456789ABCDEF" (lsh char -4)))
+	(aset ret j (aref "0123456789ABCDEF" (ash char -4)))
 	(setq j (1+ j))
 	(aset ret j (aref "0123456789ABCDEF" (logand char 15))))
       (setq j (1+ j)))
