@@ -1,6 +1,6 @@
 ;;; mew-config.el
 
-;; Author:  Kazu Yamamoto <Kazu@Mew.org>
+;; Author:  Mew developing team
 ;; Created: Dec 14, 1999
 
 ;;; Code:
@@ -151,12 +151,32 @@
 
 ;;
 
+(defun mew-prog-ssl-arg (&optional case)
+  (mew-cfent-value case "prog-ssl-arg" mew-prog-ssl-arg))
+
 (defun mew-ssl-cert-directory (&optional case)
   (mew-cfent-value case "ssl-cert-directory" mew-ssl-cert-directory))
 
 (defun mew-ssl-verify-level (&optional case)
   (mew-cfent-value case "ssl-verify-level" mew-ssl-verify-level))
 
+(defun mew-ssl-proxy-server (&optional case)
+  (mew-cfent-value case "ssl-proxy-server" mew-ssl-proxy-server))
+
+(defun mew-ssl-proxy-port (&optional case)
+  (mew-cfent-value case "ssl-proxy-port" mew-ssl-proxy-port))
+
+(defun mew-ssl-client-keycert-list (&optional case)
+  (mew-cfent-value case "ssl-client-keycert-list"
+		   mew-ssl-client-keycert-list))
+
+(defun mew-ssl-trustfiles (&optional case)
+  (mew-cfent-value case "ssl-trustfiles" mew-ssl-trustfiles))
+
+(defun mew-ssl-algorithm-priority (&optional case)
+  (mew-cfent-value case "ssl-algorithm-priority"
+		   mew-ssl-algorithm-priority))
+
 ;;
 
 (defun mew-smtp-server (&optional case)
@@ -496,6 +516,30 @@
 (defun mew-use-format-flowed (&optional case)
   (mew-cfent-value case "use-format-flowed" mew-use-format-flowed))
 
+;;
+
+(defun mew-oauth2-client-id (&optional case)
+  (mew-cfent-value case "oauth2-client-id" mew-oauth2-client-id))
+
+(defun mew-oauth2-client-secret (&optional case)
+  (mew-cfent-value case "oauth2-client-secret" mew-oauth2-client-secret))
+
+(defun mew-oauth2-redirect-url (&optional case)
+  (mew-cfent-value case "oauth2-redirect-url" mew-oauth2-redirect-url))
+
+(defun mew-oauth2-redirect-port (&optional case)
+  (mew-cfent-value case "oauth2-redirect-port" mew-oauth2-redirect-port))
+
+(defun mew-oauth2-auth-url (&optional case)
+  (mew-cfent-value case "oauth2-auth-url" mew-oauth2-auth-url))
+
+(defun mew-oauth2-token-url (&optional case)
+  (mew-cfent-value case "oauth2-token-url" mew-oauth2-token-url))
+
+(defun mew-oauth2-resource-url (&optional case)
+  (mew-cfent-value case "oauth2-resource-url" mew-oauth2-resource-url))
+
+
 ;;;
 ;;; Setting case
 ;;;
@@ -584,7 +628,7 @@ fields in the header according to the new value."
 	  (mew-draft-header-insert mew-x-mailer: mew-x-mailer)))))
 
 (defun mew-draft-get-case-by-guess (&optional alist)
-  "Guess case according to 'mew-case-guess-alist'."
+  "Guess case according to `mew-case-guess-alist'."
   (unless alist (setq alist mew-case-guess-alist))
   (let ((cases (mew-refile-guess-by-alist1 alist)))
     (if cases
@@ -611,7 +655,7 @@ fields in the header according to the new value."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2014 Mew developing team.
+;; Copyright (C) 1999-2023 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
