@@ -1,6 +1,6 @@
 ;;; mew-edit.el
 
-;; Author:  Kazu Yamamoto <Kazu@Mew.org>
+;; Author:  Mew developing team
 ;; Created: Nov  9, 1999
 
 ;;; Code:
@@ -32,19 +32,9 @@ Execute mew-dinfo-set before calling this."
 ;;;
 
 (defun mew-header-mode ()
-  "\\<mew-header-mode-map> Mew Header mode:: major mode for
-composing a MIME message by editing its header only.
+  "A major mode for composing a MIME message by editing its header only.
 
-To send the header and its body, type \\[mew-header-make-message] and \\[mew-header-send-message].
-
-Key assignment:
-
-\\[mew-header-make-message]	Compose a MIME message from the header and its body
-	then put it into a queue folder.
-\\[mew-header-send-message]	Compose a MIME message from the header and its body then send it.
-\\[mew-draft-set-case]	Guess case and set the case for output to it.
-\\[mew-draft-kill]	Kill this draft.
-"
+\\{mew-header-mode-map}"
   (interactive)
   (mew-draft-set-local-variables)
   (setq major-mode 'mew-header-mode)
@@ -53,13 +43,14 @@ Key assignment:
   (mew-header-setup-decoration)
   (mew-draft-mode-name 'header)
   (force-mode-line-update)
-  (run-hooks 'mew-header-mode-hook)
+  (mew-run-mode-hooks 'mew-header-mode-hook)
   ;; auto-fill-function is set by mew-header-mode-hook
   (when auto-fill-function
     (make-local-variable 'auto-fill-function)
     (setq auto-fill-function 'mew-draft-auto-fill)))
 
 (defmacro mew-summary-header-mode (fields &rest body)
+  ;; (declare (indent 1))
   `(mew-summary-msg-or-part
     (mew-summary-display 'redisplay)
     (mew-current-set-window-config)
@@ -79,35 +70,34 @@ Key assignment:
        (end-of-line)
        (mew-tinfo-set-hdr-file (mew-expand-msg fld msg))
        (mew-tinfo-set-field-del ,fields)))))
+(put 'mew-summary-header-mode 'lisp-indent-function 1)
 
 (defun mew-summary-send-to-others ()
   "Prepare Header mode so that this message is to be sent
 other people by a header re-write."
   (interactive)
-  (mew-summary-header-mode
-   mew-field-delete-for-others
-   (let ((case (mew-tinfo-get-case)))
-     (mew-draft-header-insert mew-to: "")
-     (mew-draft-header-insert mew-cc: (mew-cc case))
-     (mew-draft-header-insert mew-from: (mew-from case))
-     (mew-draft-header-insert mew-fcc: (mew-fcc case))
-     (mew-draft-header-insert mew-bcc: (mew-bcc case))
-     (mew-draft-header-insert mew-dcc: (mew-dcc case))
-     (mew-draft-header-insert mew-organization: (mew-organization case)))))
+  (mew-summary-header-mode mew-field-delete-for-others
+    (let ((case (mew-tinfo-get-case)))
+      (mew-draft-header-insert mew-to: "")
+      (mew-draft-header-insert mew-cc: (mew-cc case))
+      (mew-draft-header-insert mew-from: (mew-from case))
+      (mew-draft-header-insert mew-fcc: (mew-fcc case))
+      (mew-draft-header-insert mew-bcc: (mew-bcc case))
+      (mew-draft-header-insert mew-dcc: (mew-dcc case))
+      (mew-draft-header-insert mew-organization: (mew-organization case)))))
 
 (defun mew-summary-resend ()
   "Prepare Header mode so that this message is to be forwarded
 by a header re-write."
   (interactive)
-  (mew-summary-header-mode
-   mew-field-delete-for-resending
-   (let ((case (mew-tinfo-get-case)))
-     (mew-draft-header-insert mew-resent-to: "")
-     (mew-draft-header-insert mew-resent-cc: (mew-cc case))
-     (mew-draft-header-insert mew-resent-from: (mew-from case))
-     (mew-draft-header-insert mew-resent-fcc: (mew-fcc case))
-     (mew-draft-header-insert mew-resent-bcc: (mew-bcc case))
-     (mew-draft-header-insert mew-resent-dcc: (mew-dcc case)))))
+  (mew-summary-header-mode mew-field-delete-for-resending
+    (let ((case (mew-tinfo-get-case)))
+      (mew-draft-header-insert mew-resent-to: "")
+      (mew-draft-header-insert mew-resent-cc: (mew-cc case))
+      (mew-draft-header-insert mew-resent-from: (mew-from case))
+      (mew-draft-header-insert mew-resent-fcc: (mew-fcc case))
+      (mew-draft-header-insert mew-resent-bcc: (mew-bcc case))
+      (mew-draft-header-insert mew-resent-dcc: (mew-dcc case)))))
 
 (defun mew-header-process-message (action)
   (if (not (file-readable-p (mew-tinfo-get-hdr-file)))
@@ -135,16 +125,14 @@ by a header re-write."
 	(mew-current-get-window-config)
 	(mew-redraw)
 	(save-excursion
-	  (save-window-excursion
-	    (set-buffer buf)
+	  (with-current-buffer buf
 	    (mew-encode-make-backup)
 	    (mew-header-clear)
 	    ;; the end of the header
 	    (save-restriction
 	      (narrow-to-region (point) (point))
-	      (mew-frwlet
-	       mew-cs-text-for-read mew-cs-text-for-write
-	       (mew-insert-file-contents (mew-tinfo-get-hdr-file)))
+	      (mew-frwlet mew-cs-text-for-read mew-cs-text-for-write
+		(mew-insert-file-contents (mew-tinfo-get-hdr-file)))
 	      (goto-char (point-min))
 	      (mew-header-goto-end)
 	      (mew-header-set mew-header-separator)
@@ -185,16 +173,14 @@ by a header re-write."
 	(mew-current-get-window-config)
 	(mew-redraw)
 	(save-excursion
-	  (save-window-excursion
-	    (set-buffer buf)
+	  (with-current-buffer buf
 	    (mew-encode-make-backup)
 	    (mew-header-clear)
 	    ;; the end of the header
 	    (save-restriction
 	      (narrow-to-region (point) (point))
-	      (mew-frwlet
-	       mew-cs-text-for-read mew-cs-text-for-write
-	       (mew-insert-file-contents (mew-tinfo-get-hdr-file)))
+	      (mew-frwlet mew-cs-text-for-read mew-cs-text-for-write
+		(mew-insert-file-contents (mew-tinfo-get-hdr-file)))
 	      (goto-char (point-min))
 	      (mew-header-goto-end)
 	      (mew-header-set mew-header-separator)
@@ -217,13 +203,13 @@ by a header re-write."
 	      (mew-summary-visit-folder postq)))))))
 
 (defun mew-header-make-message ()
-  "Compose a MIME message from the header and its body 
+  "Compose a MIME message from the header and its body
 then put it into a queue folder."
   (interactive)
   (mew-header-process-message 'queue))
 
 (defun mew-header-send-message ()
-  "Compose a MIME message from the header and its body 
+  "Compose a MIME message from the header and its body
 then send it."
   (interactive)
   (mew-header-process-message 'send))
@@ -234,7 +220,7 @@ then send it."
 ;;;
 
 (defun mew-summary-save (&optional askcs)
-  "Save any parts. If the target is a message, you are asked which 
+  "Save any parts. If the target is a message, you are asked which
 you want to save, the entire message or its body. If the target is
 a non-message part, the part is saved (with line delimiter conversion
 if it is a text object). When executed with '\\[universal-argument]', coding-system for
@@ -280,7 +266,7 @@ a text object to be saved can be specified."
 	       (if (y-or-n-p (format "Save the entire message (y) or %s (n)? " bodyname))
 		   (setq have-hdrp t)
 		 (if plus1p
-		     (setq nums (nreverse (cons 1 (nreverse nums))))
+		     (setq nums (nconc nums '(1)))
 		   (setq bodyp t))
 		 (setq PLUS1P (mew-syntax-get-privacy body)))
 	     (setq have-hdrp t))))
@@ -310,6 +296,10 @@ a text object to be saved can be specified."
 		(string-match mew-regex-nonascii file))
 	   (setq file (mew-samba-encoding file)))
        (setq file (mew-summary-input-file-name nil file))
+       (let ((dir (mew-parent-directory file)))
+         (if (and (not (file-exists-p dir))
+                  (y-or-n-p (format "Make directory %s? " dir)))
+             (mew-make-directory dir)))
        (if (not (file-exists-p file))
 	   (setq doit t)
 	 (if (null mew-file-append-p)
@@ -331,7 +321,7 @@ a text object to be saved can be specified."
 	     (if linebasep
 		 (setq writecs mew-cs-text-for-write)
 	       (setq writecs mew-cs-binary))
-	     (when (and askcs linebasep mew-mule-p)
+	     (when (and askcs linebasep)
 	       (setq tocs (read-coding-system "Coding-system: "))
 	       (if (mew-cs-raw-p tocs)
 		   (setq writecs tocs tocs nil)))
@@ -342,7 +332,7 @@ a text object to be saved can be specified."
 	     (when tocs
 	       (setq charset (mew-syntax-get-param ctl "charset"))
 	       (if charset (setq fromcs (mew-charset-to-cs charset)))
-	       ;; When saving an entire message or its body, 
+	       ;; When saving an entire message or its body,
 	       ;; its charset is unknown since it is not analyzed.
 	       ;; So, we make use of mew-cs-autoconv.
 	       (unless (mew-coding-system-p fromcs)
@@ -352,10 +342,9 @@ a text object to be saved can be specified."
 	       (mew-cs-decode-region
 		(point-min) (point-max) (or fromcs mew-cs-autoconv))
 	       (mew-cs-encode-region (point-min) (point-max) tocs))
-	     (mew-frwlet
-	      mew-cs-dummy writecs
-	      ;; do not specify 'no-msg
-	      (write-region (point-min) (point-max) file append-p)))))))))
+	     (mew-frwlet mew-cs-dummy writecs
+	       ;; do not specify 'no-msg
+	       (write-region (point-min) (point-max) file append-p)))))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -367,98 +356,96 @@ a text object to be saved can be specified."
 according to a specified language.
 If executed with '\\[universal-argument]', coding-system is asked."
   (interactive "P")
-  (if (not mew-mule-p)
-      (message "This command cannot be used on non-Mule Emacs")
-    (mew-summary-msg-or-part
-     ;; need to make a cache or a message buffer.
-     (mew-summary-toggle-disp-msg 'on)
-     (mew-summary-display)
-     (let* ((fld (mew-summary-folder-name))
-	    (msg (mew-summary-message-number2))
-	    (num (mew-syntax-number))
-	    (nums (mew-syntax-number-to-nums num))
-	    (cbuf (mew-cache-hit fld msg))
-	    (alt  (mew-cache-dinfo-get-use-alt cbuf))
-	    (cache (or cbuf (mew-buffer-message)))
-	    (syntax (mew-syntax-get-entry (mew-cache-decode-syntax cache) nums))
-	    (buf (generate-new-buffer mew-buffer-prefix))
-	    (win (selected-window))
-	    (orig-lang current-language-environment)
-	    PLUS1P limit bodyp hbeg hend beg end start
-	    lang prompt tocs cs-env)
-       (save-excursion
-	 ;; First of all, we should determine which part the user want to
-	 ;; save due to the ambiguity.
-	 ;; "y" on Message/Rfc822
-	 ;;     - msg/txt      the entire msg or its body?
-	 ;;     - msg/mul/txt  the entire msg or its part 1?
-	 ;; We have to make use of mew-decode-syntax
-	 ;; in the cache buffer due to the PGP/MIME dilemma.
-	 ;; We need the correct LIMIT.
-	 (when (mew-syntax-message-p syntax)
-	   (let (body plus1p)
-	     (setq body (mew-syntax-get-part syntax))
-	     (when (mew-syntax-multipart-p body)
-	       (setq plus1p t)
-	       (setq body (mew-syntax-get-entry body '(1))))
-	     (if plus1p
-		 (setq nums (nreverse (cons 1 (nreverse nums))))
-	       (setq bodyp t))
-	     (setq PLUS1P (mew-syntax-get-privacy body))))
-	 ;; Now, let's analyze the message in the burst buffer.
-	 ;; This is lengthy, though, avoidable.
-	 (setq limit (length nums))
-	 (if (or PLUS1P bodyp) ;; VERY important for PGP/MIME
-	     (setq limit (1+ limit)))
-	 ;;
-	 (set-buffer buf)
-	 (mew-erase-buffer)
-	 (mew-insert-message fld msg mew-cs-text-for-read nil)
-	 ;;
-	 (cond
-	  (askcs
-	   (setq prompt
-		 (format "Coding-system (autoconv for %s): " orig-lang))
-	   (setq tocs (or (read-coding-system prompt) mew-cs-autoconv)))
-	  (t
-	   (setq tocs mew-cs-autoconv)
-	   (setq prompt (format "Language (%s): " orig-lang))
-	   (setq lang (mew-input-language-name prompt orig-lang))
-	   (setq cs-env (mew-set-language-environment-coding-systems lang))))
-	 (mew-dinfo-set limit 'no-cs-conv t alt)
-	 (mew-decode-for-edit)
-	 ;;
-	 (setq syntax (mew-syntax-get-entry mew-decode-syntax nums))
-	 (when bodyp
-	   (setq hbeg (mew-syntax-get-begin syntax))
-	   (setq hend (mew-syntax-get-end syntax))
-	   (setq syntax (mew-syntax-get-part syntax)))
-	 (setq beg (mew-syntax-get-begin syntax))
-	 (setq end (mew-syntax-get-end syntax))
-	 ;;
-	 (set-buffer (mew-buffer-message))
-	 (select-window (get-buffer-window (current-buffer)))
-	 (widen)
-	 (mew-elet
-	  (delete-region (point-min) (point-max))
-	  (when bodyp
-	    ;; This must be "insert-buffer-substring".
-	    (insert-buffer-substring buf hbeg hend)
-	    (mew-header-arrange (point-min) (point-max)))
-	  (setq start (point))
-	  (save-excursion
-	    (mew-insert-buffer-substring buf beg end)
-	    (mew-cs-decode-region start (point-max) tocs)
-	    (mew-highlight-body-region start (point-max)))
-	  ;; Page breaks
-	  (when mew-break-pages
-	    (goto-char (point-min))
-	    (mew-message-narrow-to-page))
-	  (when (and (not askcs) cs-env)
-	    (mew-reset-coding-systems (car cs-env) (cdr cs-env))))
-	 (mew-summary-display-postscript 'no-hook)
-	 (select-window win))
-       (mew-remove-buffer buf)))))
+  (mew-summary-msg-or-part
+   ;; need to make a cache or a message buffer.
+   (mew-summary-toggle-disp-msg 'on)
+   (mew-summary-display)
+   (let* ((fld (mew-summary-folder-name))
+	  (msg (mew-summary-message-number2))
+	  (num (mew-syntax-number))
+	  (nums (mew-syntax-number-to-nums num))
+	  (cbuf (mew-cache-hit fld msg))
+	  (alt  (mew-cache-dinfo-get-use-alt cbuf))
+	  (cache (or cbuf (mew-buffer-message)))
+	  (syntax (mew-syntax-get-entry (mew-cache-decode-syntax cache) nums))
+	  (buf (generate-new-buffer mew-buffer-prefix))
+	  (win (selected-window))
+	  (orig-lang current-language-environment)
+	  PLUS1P limit bodyp hbeg hend beg end start
+	  lang prompt tocs cs-env)
+     (save-excursion
+       ;; First of all, we should determine which part the user want to
+       ;; save due to the ambiguity.
+       ;; "y" on Message/Rfc822
+       ;;     - msg/txt      the entire msg or its body?
+       ;;     - msg/mul/txt  the entire msg or its part 1?
+       ;; We have to make use of mew-decode-syntax
+       ;; in the cache buffer due to the PGP/MIME dilemma.
+       ;; We need the correct LIMIT.
+       (when (mew-syntax-message-p syntax)
+	 (let (body plus1p)
+	   (setq body (mew-syntax-get-part syntax))
+	   (when (mew-syntax-multipart-p body)
+	     (setq plus1p t)
+	     (setq body (mew-syntax-get-entry body '(1))))
+	   (if plus1p
+	       (setq nums (nconc nums '(1)))
+	     (setq bodyp t))
+	   (setq PLUS1P (mew-syntax-get-privacy body))))
+       ;; Now, let's analyze the message in the burst buffer.
+       ;; This is lengthy, though, avoidable.
+       (setq limit (length nums))
+       (if (or PLUS1P bodyp) ;; VERY important for PGP/MIME
+	   (setq limit (1+ limit)))
+       ;;
+       (set-buffer buf)
+       (mew-erase-buffer)
+       (mew-insert-message fld msg mew-cs-text-for-read nil)
+       ;;
+       (cond
+	(askcs
+	 (setq prompt
+	       (format "Coding-system (autoconv for %s): " orig-lang))
+	 (setq tocs (or (read-coding-system prompt) mew-cs-autoconv)))
+	(t
+	 (setq tocs mew-cs-autoconv)
+	 (setq prompt (format "Language (%s): " orig-lang))
+	 (setq lang (read-language-name nil prompt orig-lang))
+	 (setq cs-env (mew-set-language-environment-coding-systems lang))))
+       (mew-dinfo-set limit 'no-cs-conv t alt)
+       (mew-decode-for-edit)
+       ;;
+       (setq syntax (mew-syntax-get-entry mew-decode-syntax nums))
+       (when bodyp
+	 (setq hbeg (mew-syntax-get-begin syntax))
+	 (setq hend (mew-syntax-get-end syntax))
+	 (setq syntax (mew-syntax-get-part syntax)))
+       (setq beg (mew-syntax-get-begin syntax))
+       (setq end (mew-syntax-get-end syntax))
+       ;;
+       (set-buffer (mew-buffer-message))
+       (select-window (get-buffer-window (current-buffer)))
+       (widen)
+       (mew-elet
+	(delete-region (point-min) (point-max))
+	(when bodyp
+	  ;; This must be "insert-buffer-substring".
+	  (insert-buffer-substring buf hbeg hend)
+	  (mew-header-arrange (point-min) (point-max)))
+	(setq start (point))
+	(save-excursion
+	  (mew-insert-buffer-substring buf beg end)
+	  (mew-cs-decode-region start (point-max) tocs)
+	  (mew-highlight-body-region start (point-max)))
+	;; Page breaks
+	(when mew-break-pages
+	  (goto-char (point-min))
+	  (mew-message-narrow-to-page))
+	(when (and (not askcs) cs-env)
+	  (mew-reset-coding-systems (car cs-env) (cdr cs-env))))
+       (mew-summary-display-postscript 'no-hook)
+       (select-window win))
+     (mew-remove-buffer buf))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -493,14 +480,13 @@ If executed with '\\[universal-argument]', coding-system is asked."
        ((string= (mew-syntax-get-value (mew-syntax-get-ct entry) 'cap)
 		 mew-ct-msg)
 	(setq file (mew-expand-new-msg folder (number-to-string newmsg)))
-	(mew-frwlet
-	 mew-cs-dummy mew-cs-text-for-write
-	 (write-region
-	  (mew-syntax-get-begin entry)
-	  ;; This is RFC 822 message.
-	  ;; So, body is a single text/plain.
-	  (mew-syntax-get-end (mew-syntax-get-part entry))
-	  file nil 'no-msg))
+	(mew-frwlet mew-cs-dummy mew-cs-text-for-write
+	  (write-region
+	   (mew-syntax-get-begin entry)
+	   ;; This is RFC 822 message.
+	   ;; So, body is a single text/plain.
+	   (mew-syntax-get-end (mew-syntax-get-part entry))
+	   file nil 'no-msg))
 	(mew-set-file-modes file)
 	(setq newmsg (1+ newmsg))))
       (setq n (1+ n))
@@ -546,7 +532,7 @@ If executed with '\\[universal-argument]', coding-system is asked."
 	  (setq stx (aref syntax cnt))
 	  (setq ctl (mew-syntax-get-ct stx))
 	  (setq ct (mew-syntax-get-value ctl 'cap))
-	  (cond 
+	  (cond
 	   ((string= mew-ct-msg ct)
 	    (mew-d2e-message stx dir))
 	   ((mew-ct-multipartp ct)
@@ -602,10 +588,8 @@ are decomposed. You are asked a new directory name for the decomposition."
 	 (targets FLD-MSG-LIST))
      (when (and folder (mew-local-folder-check folder 'ask))
        (message "Bursting...")
-       (while targets
-	 (mew-summary-burst-body
-	  (car (car targets)) (cdr (car targets)) folder)
-	 (setq targets (cdr targets)))
+       (dolist (target targets)
+	 (mew-summary-burst-body (car target) (cdr target) folder))
        (message "Bursting...done")
        (when mew-ask-folder-after-burst
 	 (if (y-or-n-p (format "Go to %s? " folder))
@@ -644,11 +628,10 @@ are decomposed. You are asked a new directory name for the decomposition."
 	       (goto-char (point-min))
 	       (while (re-search-forward "^- " nil t)
 		 (replace-match "" nil t))
-	       (mew-frwlet
-		mew-cs-dummy mew-cs-text-for-write
-		(write-region (point-min) (point-max)
-			      (mew-expand-new-msg folder mstr)
-			      nil 'no-msg))))
+	       (mew-frwlet mew-cs-dummy mew-cs-text-for-write
+		 (write-region (point-min) (point-max)
+			       (mew-expand-new-msg folder mstr)
+			       nil 'no-msg))))
 	   (forward-line 2)
 	   (setq start (point))
 	   (setq m (1+ m))
@@ -671,11 +654,11 @@ typically included in a MIME-encapsulated error message.
 
 1. In +draft, the message is just edited.
 2. In +queue or +postq, the message is moved to +draft and is edited.
-3. Otherwise, the message is copied to +draft and is edited. 
+3. Otherwise, the message is copied to +draft and is edited.
 
-For the other folders, if mew-case-guess-when-prepared is 't', each
+For the other folders, if mew-case-guess-when-prepared is `t', each
 fields of the original header is replaced according to a guessed
-sending case.  If called with '\\[universal-argument]', the original
+sending case.  If called with `\\[universal-argument]', the original
 header is reserved.
 
 See also mew-summary-edit-again."
@@ -701,7 +684,7 @@ See also mew-summary-edit-again."
       (t
        (if part
 	   (let* ((cache (mew-cache-hit fld msg 'must-hit))
-		  (alt (mew-cache-dinfo-get-use-alt cache))
+		  (alt nil)
 		  (syntax (mew-cache-decode-syntax cache))
 		  (stx (mew-syntax-get-entry syntax part))
 		  (ct (mew-syntax-get-value (mew-syntax-get-ct stx) 'cap)))
@@ -717,11 +700,12 @@ See also mew-summary-edit-again."
 ;;; Header
 ;;;
 
-(defsubst mew-summary-edit-header-common ()
+(defun mew-summary-edit-header-common ()
   (mew-header-delete-lines (list mew-x-mailer:))
   (mew-header-goto-end)
   ;; X-Mailer: must be the last
-  (mew-draft-header-insert mew-x-mailer: mew-x-mailer)
+  (if (mew-use-x-mailer (mew-tinfo-get-case))
+      (mew-draft-header-insert mew-x-mailer: mew-x-mailer))
   (mew-header-clear) ;; erase the old header separator
   (mew-header-set "\n"))
 
@@ -841,8 +825,8 @@ The message is assumed to be a valid MIME message."
 
 (defun mew-summary-edit-again ()
   "Edit an old fashioned error message in which the original message
-is encapsulated after strings defined in 'mew-summary-edit-again-regex'
-An example is \"----- Original message follows -----\". See also 
+is encapsulated after strings defined in `mew-summary-edit-again-regex'
+An example is \"----- Original message follows -----\". See also
 mew-summary-reedit."
   (interactive)
   (mew-summary-msg
@@ -864,9 +848,8 @@ mew-summary-reedit."
 	 (while (looking-at "^$") (forward-line))
 	 (delete-region (point-min) (point))
 	 (setq nfile (mew-expand-new-msg nfld nmsg))
-	 (mew-frwlet
-	  mew-cs-dummy mew-cs-text-for-write
-	  (write-region (point-min) (point-max) nfile nil 'no-msg))
+	 (mew-frwlet mew-cs-dummy mew-cs-text-for-write
+	   (write-region (point-min) (point-max) nfile nil 'no-msg))
 	 ;; A new message is stored in the temporary directory
 	 (mew-summary-reedit-for-message nfld nmsg nil nil nil)
 	 (run-hooks 'mew-draft-mode-edit-again-hook)
@@ -881,18 +864,17 @@ mew-summary-reedit."
   "Get an appropriate suffix from content type."
   (let* ((base (mew-ctdb-regex (mew-ctdb-by-ct ct)))
 	 (len (length base))
-	 (ret (make-string len ?a))
-	 (i 0) (j 0) char)
+	 (ret (mew-make-string len))
+	 (j 0) char)
     (if (not (stringp base))
 	nil
-      (while (< i len)
+      (dotimes (i len)
 	(setq char (aref base i))
 	(if (or (char-equal char ?.)
 		(and (>= char ?a) (<= char ?z)))
 	    (progn
 	      (aset ret j char)
-	      (setq j (1+ j))))
-	(setq i (1+ i)))
+	      (setq j (1+ j)))))
       (setq ret (substring ret 0 j))
       (if (string-match "^\\.[a-z]+$" ret)
 	  ret
@@ -908,14 +890,13 @@ mew-summary-reedit."
     (mew-draft-find-and-switch draft)
     (mew-delete-directory-recursively attachdir)
     ;; De-compose the message in the burst buffer.
-    ;; do not decode Message/Rfc822 parts. 
+    ;; do not decode Message/Rfc822 parts.
     ;; They will be just a attachment message.
-    (save-excursion
+    (with-current-buffer buf
       ;; Let's decode the message without limitations
-      (set-buffer buf)
       (mew-erase-buffer)
       (mew-insert-message fld msg mew-cs-text-for-read nil)
-      (mew-dinfo-set (1+ (length part)) 'no-cs-conv t alt)
+      (mew-dinfo-set (1+ (length part)) 'no-cs-conv t alt 'encap-html)
       (mew-decode-for-edit)
       (setq syntax (mew-syntax-get-entry mew-decode-syntax part))
       ;; syntax is now for the message
@@ -944,7 +925,7 @@ mew-summary-reedit."
 	  (setq stx (aref syntax cnt))
 	  (setq ctl (mew-syntax-get-ct stx))
 	  (setq ct (mew-syntax-get-value ctl 'cap))
-	  (cond 
+	  (cond
 	   ((string= mew-ct-msg ct)
 	    (mew-d2e-message stx attachdir))
 	   ((mew-ct-multipartp ct)
@@ -999,10 +980,8 @@ mew-summary-reedit."
 	(setq file (expand-file-name file dir))
       (setq file (mew-random-filename dir 2 nil (mew-ct-suffix ct)))
       (mew-syntax-set-cdp syntax nil))
-    (mew-frwlet
-     mew-cs-dummy
-     (if linebasep mew-cs-text-for-write mew-cs-binary)
-     (write-region beg end file nil 'no-msg))
+    (mew-frwlet mew-cs-dummy (if linebasep mew-cs-text-for-write mew-cs-binary)
+      (write-region beg end file nil 'no-msg))
     (if (and (mew-ct-textp ct) (mew-syntax-get-param ctl "charset"))
 	(mew-delete "charset" ctl)) ;; side effect
     (mew-syntax-set-file syntax (file-name-nondirectory file))
@@ -1019,7 +998,7 @@ mew-summary-reedit."
     (while (< cnt len)
       (setq part (aref syntax cnt))
       (setq ct (mew-syntax-get-value (mew-syntax-get-ct part) 'cap))
-      (cond 
+      (cond
        ((string= mew-ct-msg ct)
 	(mew-d2e-message part dir))
        ((mew-ct-multipartp ct)
@@ -1043,9 +1022,8 @@ mew-summary-reedit."
   (let ((file (mew-random-filename dir 2 t))
 	(beg (mew-syntax-get-begin syntax))
 	(end (mew-syntax-get-end (mew-syntax-get-part syntax))))
-    (mew-frwlet
-     mew-cs-dummy mew-cs-text-for-write
-     (write-region beg end file nil 'no-msg))
+    (mew-frwlet mew-cs-dummy mew-cs-text-for-write
+      (write-region beg end file nil 'no-msg))
     (mew-syntax-set-key syntax 'single)
     (mew-syntax-set-file syntax (file-name-nondirectory file))
     (mew-syntax-set-decrypters syntax nil)
@@ -1054,17 +1032,156 @@ mew-summary-reedit."
     (mew-syntax-set-cdp syntax nil)
     (mew-syntax-set-part syntax nil)))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Edit mode
+;;;
+
+(defun mew-summary-edit ()
+  (interactive)
+  (mew-summary-not-in-queue
+   (mew-summary-not-in-draft
+    (mew-summary-msg-or-part
+     (let ((fld (mew-summary-folder-name))
+	   (msg (mew-summary-message-number2))
+	   (part (mew-syntax-nums)))
+       (if part
+	   (let* ((cache (mew-cache-hit fld msg 'must-hit))
+		  (alt nil)
+		  (syntax (mew-cache-decode-syntax cache))
+		  (stx (mew-syntax-get-entry syntax part))
+		  (ct (mew-syntax-get-value (mew-syntax-get-ct stx) 'cap)))
+	     (if (not (string= mew-ct-msg ct))
+		 (message "Cannot edit here")
+	       (mew-summary-edit-for-message fld msg part alt)
+	       (run-hooks 'mew-draft-mode-edit-hook)))
+	 (mew-summary-edit-for-message fld msg nil nil)
+	 (setq mode-name "Edit")
+	 (force-mode-line-update)
+	 (run-hooks 'mew-draft-mode-edit-hook)))))))
+
+(defun mew-summary-edit-for-message (fld msg part alt)
+  (mew-current-set-window-config)
+  (mew-window-configure 'draft)
+  ;; main part
+  (mew-summary-prepare-draft
+   ;; case is copied here
+   (mew-summary-edit-message fld msg part alt)
+   ;; get info before backup the original
+   (mew-summary-edit-header-for-edit)
+   (let ((fields (mew-summary-edit-obtain-fields-key)))
+     (mew-tinfo-set-preserved-header (mew-summary-edit-obtain-fields fld msg fields)))
+   (mew-tinfo-set-src-folder fld)
+   (mew-draft-mode)
+   (mew-draft-rehighlight-body)
+   (when mew-encode-syntax
+     (save-excursion
+       (mew-draft-prepare-attachments t)))
+   (mew-draft-mode-name)))
+
+(defun mew-summary-edit-header-for-edit ()
+  (mew-elet
+   (mew-header-delete-lines '("From " ">From"))
+   (mew-header-delete-lines mew-field-delete-for-editing)
+   (mew-header-sort mew-field-order-for-editing)
+   (mew-header-clear) ;; erase the old header separator
+   (mew-header-set "\n")))
+
+(defun mew-summary-edit-obtain-fields-key ()
+  (let ((case-fold-search t) fields)
+    (save-excursion
+      (mew-header-goto-end)
+      (save-restriction
+	(narrow-to-region (point-min) (point))
+	(goto-char (point-min))
+	(while (not (eobp))
+	  (if (not (looking-at mew-keyval))
+	      (forward-line)
+	    (setq fields (cons (mew-match-string 1) fields))
+            (forward-line)
+	    (mew-header-goto-next))))
+      fields)))
+
+(defun mew-summary-edit-obtain-fields (fld msg fields)
+  (with-temp-buffer
+    (mew-insert-message
+     fld msg mew-cs-text-for-read mew-header-reasonable-size)
+    (mew-header-goto-end)
+    (delete-region (point) (point-max))
+    (mew-header-delete-lines fields)
+    (mew-header-delete-lines (list mew-mv: "Content-" "X-Mew-"))
+    (mew-buffer-substring (point-min) (point-max))))
+
+(defun mew-edit-make-delete-window (buf)
+  (if (and (mew-tinfo-get-other-frame) (> (length (frame-list)) 1))
+      (delete-frame)
+    (mew-current-get-window-config)
+    (delete-windows-on buf))) ;; just in case
+
+(defun mew-edit-make-message (buf)
+  (let (multip)
+    (save-excursion
+      (save-window-excursion
+	(set-buffer buf)
+	(mew-set-buffer-multibyte t)
+	(if (buffer-modified-p) (save-buffer)) ;; to make backup
+	(widen)
+	(if (mew-attach-p)
+	    (progn
+	      (setq multip t)
+	      (mew-attach-clear))
+	  (unless mew-encode-syntax
+	    (setq mew-encode-syntax
+		  (mew-encode-syntax-single "text.txt" (list mew-ct-txt)))))
+	(goto-char (mew-header-end))
+	(forward-line)
+	(if multip
+	    (mew-encode-make-multi)
+	  (mew-encode-make-single))
+	(mew-encode-make-header)
+	(mew-encode-save-draft)
+	(mew-overlay-delete-buffer)
+	(goto-char (point-min))
+	(insert (mew-tinfo-get-preserved-header))
+	(save-buffer)
+	(buffer-file-name)))))
+
+(defun mew-edit-make-refile (case:srcfld srcfile)
+  (let* ((case:dstfld (car (mew-input-folders case:srcfld)))
+	 (dstfld (mew-case:folder-folder case:dstfld))
+	 (case (mew-case:folder-case case:dstfld))
+	 dstfile)
+    (cond
+     ((mew-folder-imapp dstfld)
+      (mew-imap2-copy-message case 'move (list srcfile) dstfld))
+     (t
+      (setq dstfile (mew-folder-new-message dstfld))
+      (rename-file srcfile dstfile)
+      (mew-set-file-modes dstfile)
+      (mew-touch-folder dstfld)
+      (message "Saved in %s" dstfld)))))
+
+(defun mew-edit-make ()
+  (interactive)
+  (let ((buf (current-buffer))
+	(case:srcfld (mew-tinfo-get-src-folder))
+	srcfile)
+    (mew-edit-make-delete-window buf)
+    (setq srcfile (mew-edit-make-message buf))
+    (mew-remove-buffer buf)
+    (mew-edit-make-refile case:srcfld srcfile)))
+
 (provide 'mew-edit)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2007 Mew developing team.
+;; Copyright (C) 1999-2023 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
 ;; modification, are permitted provided that the following conditions
 ;; are met:
-;; 
+;;
 ;; 1. Redistributions of source code must retain the above copyright
 ;;    notice, this list of conditions and the following disclaimer.
 ;; 2. Redistributions in binary form must reproduce the above copyright
@@ -1073,7 +1190,7 @@ mew-summary-reedit."
 ;; 3. Neither the name of the team nor the names of its contributors
 ;;    may be used to endorse or promote products derived from this software
 ;;    without specific prior written permission.
-;; 
+;;
 ;; THIS SOFTWARE IS PROVIDED BY THE TEAM AND CONTRIBUTORS ``AS IS'' AND
 ;; ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 ;; IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
