@@ -1,10 +1,12 @@
 ;;; mew-gemacs.el --- Environment of Graphical Emacs for Mew
 
-;; Author:  Kazu Yamamoto <Kazu@Mew.org>
+;; Author:  Mew developing team
 ;; Created: Jun 22, 2000
 
 ;;; Code:
 
+(require 'mew)
+
 (defvar mew-prog-pamscale (or (executable-find "pamscale") "pnmscale"))
 (defvar mew-prog-pamscale-opt
   (cond
@@ -143,7 +145,8 @@
   :type 'boolean)
 
 (defcustom mew-image-display-resize-always nil
-  "*If nil, only a larger image than frame size will be displayed with fitting to frame size"
+  "*If nil, only a larger image than frame size will be displayed
+with fitting to frame size"
   :group 'mew-message
   :type 'boolean)
 
@@ -199,7 +202,7 @@
 	   ((or (eq c ?\xd8)                      ;; SOI
 		(eq c ?\xd9)                      ;; EOI
 		(and (>= c ?\xd0) (<= c ?\xd7)))) ;; RSTm
-	   ((eq c ?\xc0)
+	   ((or (eq c ?\xc0) (eq c ?\xc2))
 	    (forward-char 3)
 	    (setq height (mew-img-get-n mew-image-b-endian 2))
 	    (setq width (mew-img-get-n mew-image-b-endian 2))
@@ -434,7 +437,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2015 Mew developing team.
+;; Copyright (C) 1997-2023 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
