@@ -153,10 +153,7 @@
 (defun mew-highlight-body-region (BEG END &optional draft rehighlight)
   (when (and (or mew-use-highlight-body mew-use-highlight-url)
 	     (or (= 0 mew-highlight-body-max-size)
-		 (<= BEG mew-highlight-body-max-size)))
-    (unless (or (= 0 mew-highlight-body-max-size)
-		(<= END mew-highlight-body-max-size))
-      (setq END mew-highlight-body-max-size))
+		 (<= (- END BEG) mew-highlight-body-max-size)))
     (let* ((inhibit-point-motion-hooks t)
 	   (cite-regex mew-highlight-body-regex-cite)
 	   (cmt-regex mew-highlight-body-regex-comment)
