@@ -7,6 +7,8 @@
 
 (require 'mew)
 
+(declare-function string-replace "subr")
+
 (defvar mew-imap-msgid-file ".mew-msgid")
 (defvar mew-imap-folder-alist-file ".mew-folder-alist")
 (defvar mew-imap-folder-alist nil)
@@ -30,7 +32,7 @@
 ;;;
 
 (defvar mew-imap-info-list
-  '("server" "port" "process" "ssh-process" "ssl-process" "status"
+  '("server" "port" "process" "ssh-process" "ssl-process" "ssl-p" "status"
     "directive" "bnm" "mdb"
     "rmvs" "kils" "refs" "movs"
     "rtrs" "dels" "uidl" "range"
@@ -56,6 +58,7 @@
 (defvar mew-imap-fsm
   '(("greeting"      ("OK" . "capability"))
     ("capability"    ("OK" . "post-capability"))
+    ("auth-xoauth2"  ("OK" .  "next") ("NO" . "xoauth2-wpwd"))
     ("auth-cram-md5" ("OK" . "pwd-cram-md5") ("NO" . "wpwd"))
     ("pwd-cram-md5"  ("OK" . "next") ("NO" . "wpwd"))
     ("auth-login"    ("OK" . "user-login") ("NO" . "wpwd"))
@@ -104,7 +107,7 @@
 ;;;
 
 (defun mew-imap-secure-p (pnm)
-  (or (mew-imap-get-ssh-process pnm) (mew-imap-get-ssl-process pnm)))
+  (or (mew-imap-get-ssh-process pnm) (mew-imap-get-ssl-p pnm)))
 
 (defun mew-imap-command-capability (pro pnm)
   (mew-net-status (mew-imap-get-status-buf pnm)
@@ -969,7 +972,8 @@
 
 (defvar mew-imap-auth-alist
   '(("CRAM-MD5" mew-imap-command-auth-cram-md5)
-    ("LOGIN"    mew-imap-command-auth-login)))
+    ("LOGIN"    mew-imap-command-auth-login)
+    ("XOAUTH2"  mew-imap-command-auth-xoauth2)))
 
 (defun mew-imap-auth-get-func (auth)
   (nth 1 (mew-assoc-case-equal auth mew-imap-auth-alist 0)))
@@ -1007,6 +1011,23 @@
 	 (epasswd (mew-base64-encode-string passwd)))
     (mew-imap-process-send-string2 pro epasswd)))
 
+;;;;;;;;;;;;;;;;
+;; XOAUTH2
+
+(defun mew-imap-command-auth-xoauth2 (pro pnm)
+  (let* ((user (mew-imap-get-user pnm))
+	 (tag (mew-imap-passtag pnm))
+         (auth-string (mew-xoauth2-auth-string user tag (mew-imap-get-case pnm))))
+    (mew-imap-process-send-string pro pnm (format "AUTHENTICATE XOAUTH2 %s" auth-string))
+    (mew-imap-set-status pnm "auth-xoauth2")))
+
+(defun mew-imap-command-xoauth2-wpwd (pro pnm)
+  (mew-imap-set-done pnm t)
+  (mew-passwd-set-passwd (mew-imap-passtag pnm) nil)
+  (delete-process pro)
+  ;; XXX: Should be cared more! Clear process and filter without sending LOGOUT.
+  (error "IMAP XOAUTH2 token is wrong!"))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Sub functions
@@ -1224,14 +1245,18 @@
 ;;; Opening IMAP
 ;;;
 
-(defun mew-imap-open (pnm server port no-msg)
+(defun mew-imap-open (pnm case server port no-msg starttlsp)
   (let ((sprt (mew-*-to-port port))
+	(sslnp (mew-ssl-native-p (mew-imap-ssl case)))
 	pro tm)
     (condition-case emsg
 	(progn
 	  (setq tm (run-at-time mew-imap-timeout-time nil 'mew-imap-timeout))
 	  (or no-msg (message "Connecting to the IMAP server..."))
-	  (setq pro (open-network-stream pnm nil server sprt))
+	  (setq pro (mew-open-network-stream pnm nil server sprt
+					     'imap sslnp starttlsp case))
+	  (setq pro (car pro))
+	  (when (not (processp pro)) (signal 'quit nil))
 	  (mew-process-silent-exit pro)
 	  (mew-set-process-cs pro mew-cs-binary mew-cs-text-for-net)
 	  (or no-msg (message "Connecting to the IMAP server...done")))
@@ -1245,7 +1270,11 @@
     pro))
 
 (defun mew-imap-timeout ()
-  (signal 'quit nil))
+  ;; Do not timeout if the NSM query pane is active.
+  (unless (get-buffer "*Network Security Manager*")
+    (message "IMAP connection timed out (%d seconds)"
+	     mew-imap-timeout-time)
+    (signal 'quit nil)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -1267,6 +1296,8 @@
 	  (setq ret (cons (mew-make-mark-hist :msg msg :mark mew-mark-read) ret))))))
     (nreverse ret)))
 
+(defvar mew--gnutls-imap-greeting nil)
+
 (defun mew-imap-retrieve (case directive bnm &rest args)
   (let* ((server (mew-imap-server case))
          (user (mew-imap-user case))
@@ -1274,6 +1305,11 @@
 	 (sshsrv (mew-imap-ssh-server case))
 	 (sslp (mew-imap-ssl case))
 	 (sslport (mew-imap-ssl-port case))
+	 (sslnp (mew-ssl-native-p (mew-imap-ssl case)))
+	 (starttlsp
+	  (mew-ssl-starttls-p (mew-imap-ssl case)
+			      (mew-*-to-string (mew-imap-port case))
+			      (mew-imap-ssl-port case)))
 	 (proxysrv (mew-imap-proxy-server case))
 	 (proxyport (mew-imap-proxy-port case))
 	 ;; dirty but necessary for migration
@@ -1288,29 +1324,32 @@
     (if (mew-imap-get-process pnm)
 	(message "Another IMAP process is running. Try later")
       (cond
+       (sslnp
+	(let ((serv (if starttlsp port sslport)))
+	  (setq process (mew-imap-open pnm case server serv no-msg starttlsp))))
        (sshsrv
 	(setq sshpro (mew-open-ssh-stream case server port sshsrv))
 	(when sshpro
 	  (setq sshname (process-name sshpro))
 	  (setq lport (mew-ssh-pnm-to-lport sshname))
 	  (when lport
-	    (setq process (mew-imap-open pnm "localhost" lport no-msg)))))
+	    (setq process (mew-imap-open pnm case "localhost" lport no-msg nil)))))
        (sslp
-	(if (mew-port-equal port sslport) (setq tls mew-tls-imap))
+	(when starttlsp (setq tls mew-tls-imap))
 	(setq sslpro (mew-open-ssl-stream case server sslport tls))
 	(when sslpro
 	  (setq sslname (process-name sslpro))
 	  (setq lport (mew-ssl-pnm-to-lport sslname))
 	  (when lport
-	    (setq process (mew-imap-open pnm mew-ssl-localhost lport no-msg)))))
+	    (setq process (mew-imap-open pnm case mew-ssl-localhost lport no-msg nil)))))
        (proxysrv
-	(setq process (mew-imap-open pnm proxysrv proxyport no-msg)))
+	(setq process (mew-imap-open pnm case proxysrv proxyport no-msg nil)))
        (t
-	(setq process (mew-imap-open pnm server port no-msg))))
+	(setq process (mew-imap-open pnm case server port no-msg nil))))
       (if (null process)
 	  (when (eq directive 'exec)
 	    (mew-imap-exec-recover bnm))
-	(mew-summary-lock process "IMAPing" (or sshpro sslpro))
+	(mew-summary-lock process "IMAPing" (or sshpro sslp))
 	(mew-sinfo-set-summary-form (mew-get-summary-form bnm))
 	(mew-sinfo-set-summary-column (mew-get-summary-column bnm))
 	(mew-sinfo-set-unread-mark nil)
@@ -1322,6 +1361,7 @@
 	(mew-imap-set-process pnm process)
 	(mew-imap-set-ssh-process pnm sshpro)
 	(mew-imap-set-ssl-process pnm sslpro)
+	(mew-imap-set-ssl-p pnm sslp)
 	(mew-imap-set-server pnm server)
 	(mew-imap-set-port pnm port)
 	(mew-imap-set-user pnm user)
@@ -1361,7 +1401,7 @@
 	  (when virtual
 	    (mew-imap-set-status-buf pnm virtual)
 	    (with-current-buffer virtual
-	      (mew-summary-lock process "IMAPing" (or sshpro sslpro)))))
+	      (mew-summary-lock process "IMAPing" (or sshpro sslp)))))
 	 ((eq directive 'scan)
 	  (mew-imap-set-range pnm (nth 0 args))
 	  (mew-imap-set-get-body pnm (nth 1 args))
@@ -1403,7 +1443,17 @@
 	;;
 	(set-process-sentinel process 'mew-imap-sentinel)
 	(set-process-filter process 'mew-imap-filter)
-	(set-process-buffer process buf)))))
+	(set-process-buffer process buf)
+	;;
+	(when sslnp
+	  ;; GnuTLS receives IMAP greeting in its internals
+	  ;; and passes it as a return value.
+	  ;; We store the value in the variable mew--gnutls-imap-greeting
+	  ;; and pass it to the filter to process the greeting.
+	  (mew-imap-filter process
+			  (string-replace "\r\n" "\n"
+					  mew--gnutls-imap-greeting)))
+	))))
 
 (defun mew-imap-exec-recover (bnm)
   (mew-summary-visible-buffer bnm)
@@ -1477,8 +1527,12 @@
        (if (string= status "greeting")
 	   (setq next (mew-imap-fsm-next "greeting" "OK"))
 	 (setq stay t)))
-      ((and (goto-char (point-min)) (looking-at "\\+"))
-       (setq next (mew-imap-fsm-next status "OK")))
+      ((and (goto-char (point-min)) (looking-at "\\+ *\\(.*\\)"))
+       (setq next (mew-imap-fsm-next
+                   status
+                   (if (string= status "auth-xoauth2")
+                       (mew-xoauth2-json-status (mew-match-string 1))
+                     "OK"))))
       ((and (goto-char (point-max)) (= (forward-line -1) 0) (looking-at eos))
        (mew-imap-set-tag pnm nil)
        (setq code (mew-match-string 1))
@@ -1548,7 +1602,8 @@
 	 (file (mew-expand-file bnm mew-imap-msgid-file))
 	 (buf (process-buffer process))
 	 (virtual-info (mew-imap-get-virtual-info pnm))
-	 (disp-info (mew-imap-get-disp-info pnm)))
+	 (disp-info (mew-imap-get-disp-info pnm))
+	 (sinfo-mark-hist (mew-sinfo-get-mark-hist)))
     (save-excursion
       (mew-imap-debug "IMAP SENTINEL" event)
       (set-process-buffer process nil)
@@ -1615,7 +1670,9 @@
 	  (mew-net-uidl-db-set (mew-imap-passtag pnm) uidl)
 	  (cond
 	   ((= rttl 0)
-	    (mew-imap-message pnm "No new messages"))
+	    (mew-imap-message pnm "No new messages")
+	    (when sinfo-mark-hist
+	      (mew-summary-folder-cache-save)))
 	   ((= rttl 1)
 	    (mew-imap-message pnm "1 message retrieved")
 	    (mew-summary-folder-cache-save))
@@ -1625,7 +1682,9 @@
 	 ((eq directive 'get)
 	  (cond
 	   ((= rttl 0)
-	    (mew-imap-message pnm "The message does not exist"))
+	    (mew-imap-message pnm "The message does not exist")
+	    (when sinfo-mark-hist
+	      (mew-summary-folder-cache-save)))
 	   ((= rttl 1)
 	    (mew-imap-message pnm "1 message retrieved")
 	    (mew-summary-folder-cache-save))
@@ -1636,7 +1695,9 @@
 	  (mew-biff-clear)
 	  (cond
 	   ((or (= rttl 0) (null msgid))
-	    (mew-imap-message pnm "No new messages"))
+	    (mew-imap-message pnm "No new messages")
+	    (when sinfo-mark-hist
+	      (mew-summary-folder-cache-save)))
 	   ((= rttl 1)
 	    (mew-imap-message pnm "1 message retrieved")
 	    (mew-lisp-save file msgid nil 'unlimit)
@@ -1652,7 +1713,8 @@
 		  (mew-inherit-offline t))
 	      (mew-mark-exec-refile bnm movs)))
 	  (when (or kils movs)
-	    (mew-mark-kill-invisible)
+	    (mew-mark-kill-invisible))
+	  (when (or kils movs sinfo-mark-hist)
 	    (mew-summary-folder-cache-save))
 	  (cond
 	   ((= rttl 1)
