@@ -37,6 +37,7 @@
 (defvar mew-imap2-fsm
   '(("greeting"      ("OK" . "capability"))
     ("capability"    ("OK" . "post-capability"))
+    ("auth-xoauth2"  ("OK" .  "next") ("NO" . "xoauth2-wpwd"))
     ("auth-cram-md5" ("OK" . "pwd-cram-md5") ("NO" . "wpwd"))
     ("pwd-cram-md5"  ("OK" . "next") ("NO" . "wpwd"))
     ("auth-login"    ("OK" . "user-login") ("NO" . "wpwd"))
@@ -241,7 +242,8 @@
 
 (defvar mew-imap2-auth-alist
   '(("CRAM-MD5" mew-imap2-command-auth-cram-md5)
-    ("LOGIN"    mew-imap2-command-auth-login)))
+    ("LOGIN"    mew-imap2-command-auth-login)
+    ("XOAUTH2"  mew-imap2-command-auth-xoauth2)))
 
 (defun mew-imap2-auth-get-func (auth)
   (nth 1 (mew-assoc-case-equal auth mew-imap2-auth-alist 0)))
@@ -278,6 +280,24 @@
          (epasswd (mew-base64-encode-string passwd)))
     (mew-imap2-process-send-string2 pro epasswd)))
 
+;;;;;;;;;;;;;;;;
+;; XOAUTH2
+
+(defun mew-imap2-command-auth-xoauth2 (pro pnm)
+  (let* ((user (mew-imap2-get-user pnm))
+	 (tag (mew-imap2-passtag pnm))
+         (auth-string (mew-xoauth2-auth-string user tag (mew-imap-get-case pnm))))
+    ;; XXX: need to reset satus if token is nil.
+    (mew-imap2-process-send-string pro pnm (format "AUTHENTICATE XOAUTH2 %s" auth-string))
+    (mew-imap2-set-status pnm "auth-xoauth2")))
+
+(defun mew-imap2-command-xoauth2-wpwd (pro pnm)
+  (mew-imap2-set-done pnm t)
+  (mew-passwd-set-passwd (mew-imap2-passtag pnm) nil)
+  (delete-process pro)
+  ;; XXX: Should be cared more! Clear process and filter without sending LOGOUT.
+  (error "IMAP XOAUTH2 token is wrong!"))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Sub functions
@@ -360,14 +380,18 @@
 ;;; Opening IMAP
 ;;;
 
-(defun mew-imap2-open (pnm server port)
+(defun mew-imap2-open (pnm case server port starttlsp)
   (let ((sprt (mew-*-to-port port))
+	(sslnp (mew-ssl-native-p (mew-imap-ssl case)))
 	pro tm)
     (condition-case emsg
 	(progn
 	  (setq tm (run-at-time mew-imap-timeout-time nil 'mew-imap2-timeout))
 	  (message "Connecting to the IMAP server...")
-	  (setq pro (open-network-stream pnm nil server sprt))
+	  (setq pro (mew-open-network-stream pnm nil server sprt
+					     'imap sslnp starttlsp case))
+	  (setq pro (car pro))
+	  (when (not (processp pro)) (signal 'quit nil))
 	  (mew-process-silent-exit pro)
 	  (mew-set-process-cs pro mew-cs-text-for-net mew-cs-text-for-net)
 	  (message "Connecting to the IMAP server...done"))
@@ -381,7 +405,11 @@
     pro))
 
 (defun mew-imap2-timeout ()
-  (signal 'quit nil))
+  ;; Do not timeout if the NSM query pane is active.
+  (unless (get-buffer "*Network Security Manager*")
+    (message "IMAP connection timed out (%d seconds)"
+	     mew-imap-timeout-time)
+    (signal 'quit nil)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -396,29 +424,37 @@
 	 (sshsrv (mew-imap-ssh-server case))
 	 (sslp (mew-imap-ssl case))
 	 (sslport (mew-imap-ssl-port case))
+	 (sslnp (mew-ssl-native-p (mew-imap-ssl case)))
+	 (starttlsp
+	  (mew-ssl-starttls-p (mew-imap-ssl case)
+			      (mew-*-to-string (mew-imap-port case))
+			      (mew-imap-ssl-port case)))
 	 (proxysrv (mew-imap-proxy-server case))
 	 (proxyport (mew-imap-proxy-port case))
 	 process sshname sshpro sslname sslpro lport tls)
     (cond
+     (sslnp
+      (let ((serv (if starttlsp port sslport)))
+	(setq process (mew-imap2-open pnm case server serv starttlsp))))
      (sshsrv
       (setq sshpro (mew-open-ssh-stream case server port sshsrv))
       (when sshpro
 	(setq sshname (process-name sshpro))
 	(setq lport (mew-ssh-pnm-to-lport sshname))
 	(when lport
-	  (setq process (mew-imap2-open pnm "localhost" lport)))))
+	  (setq process (mew-imap2-open pnm case "localhost" lport nil)))))
      (sslp
-      (if (mew-port-equal port sslport) (setq tls mew-tls-imap))
+      (when starttlsp (setq tls mew-tls-imap))
       (setq sslpro (mew-open-ssl-stream case server sslport tls))
       (when sslpro
 	(setq sslname (process-name sslpro))
 	(setq lport (mew-ssl-pnm-to-lport sslname))
 	(when lport
-	  (setq process (mew-imap2-open pnm mew-ssl-localhost lport)))))
+	  (setq process (mew-imap2-open pnm case mew-ssl-localhost lport nil)))))
      (proxysrv
-      (setq process (mew-imap2-open pnm proxysrv proxyport)))
+      (setq process (mew-imap2-open pnm case proxysrv proxyport nil)))
      (t
-      (setq process (mew-imap2-open pnm server port))))
+      (setq process (mew-imap2-open pnm case server port nil))))
     (if (null process)
 	(cond
 	 ((and sshsrv (null sshpro))
@@ -448,7 +484,14 @@
       (set-process-buffer process nil)
       (set-process-sentinel process 'mew-imap2-sentinel)
       (set-process-filter process 'mew-imap2-filter)
-      (message "Copying in background..."))))
+      (message "Copying in background...")
+      (when sslnp
+	;; GnuTLS requires a client-initiated command after the
+	;; session is established or upgraded to use TLS because
+	;; no additional greeting from the server.
+	(mew-imap2-set-status pnm "capability")
+	(mew-imap2-command-capability process pnm))
+      )))
 
 (defun mew-summary-from-local-to-imap ()
   "Copy messages in local folders under specified folder prefix
@@ -537,7 +580,7 @@ with '*' in the region are handled."
 	 (buf (process-buffer process))
 	 aux stay next func code resp)
     (save-excursion
-      (mew-imap2-debug (upcase status) string)
+      (mew-imap2-debug (upcase (format "%s" status)) string)
       (if (and buf (get-buffer buf)) (set-buffer buf))
       (while (string-match "^\\*[^\n]*\n" str)
 	(setq aux (substring str 0 (match-end 0)))
@@ -551,9 +594,14 @@ with '*' in the region are handled."
       (cond
        (next
 	nil)
-       ((string-match "^\\+" str)
+       ((string-match "^\\+ *\\(.*\\)" str)
 	(mew-imap2-set-aux pnm str)
-	(setq next (mew-imap2-fsm-next status "OK")))
+        (setq next (mew-imap2-fsm-next
+                    status
+                    (if (string= status "auth-xoauth2")
+                        (mew-xoauth2-json-status (mew-match-string 1))
+			"OK"
+                      "OK"))))
        ((string-match eos str)
 	(mew-imap2-set-tag pnm nil)
 	(setq code (mew-match-string 1 str))
