@@ -1,6 +1,6 @@
 ;;; mew-minibuf.el --- Minibuffer input methods for Mew
 
-;; Author:  Kazu Yamamoto <Kazu@Mew.org>
+;; Author:  Mew developing team
 ;; Created: Mar 23, 1997
 
 ;;; Code:
@@ -14,18 +14,18 @@
 
 (defvar mew-input-complete-function nil
   "A function to be called when TAB is typed in minibuffer.
-This is used in 'mew-input-complete'.")
+This is used in `mew-input-complete'.")
 
 (defun mew-input-complete ()
   "Do completion according to the global variable
-\"mew-input-complete-function\"."
+`mew-input-complete-function'."
   (interactive)
   (if (and mew-input-complete-function (fboundp mew-input-complete-function))
       (funcall mew-input-complete-function)))
 
 (defvar mew-input-exit-minibuffer-function nil
   "A function to be called when RET is typed in minibuffer.
-This function are used to check validity of 'case' and sort key.")
+This function are used to check validity of `case' and sort key.")
 
 (defun mew-input-exit-minibuffer ()
   "Ensure the input meets a condition."
@@ -36,8 +36,8 @@ This function are used to check validity of 'case' and sort key.")
       (exit-minibuffer)))
 
 (defvar mew-input-comma-function nil
-  "A function to be called when ',' is typed in minibuffer.
-This function can be used to check validity of 'case'.")
+  "A function to be called when `,' is typed in minibuffer.
+This function can be used to check validity of `case'.")
 
 (defun mew-input-comma ()
   "Ensure the input meets a condition."
@@ -1027,7 +1027,7 @@ it is deleted automatically."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2015 Mew developing team.
+;; Copyright (C) 1997-2023 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
