@@ -7,6 +7,8 @@
 
 (require 'mew)
 
+(declare-function string-replace "subr")
+
 (defvar mew-pop-msgid-file ".mew-msgid")
 (defvar mew-pop-folder-alist (list (mew-folder-func mew-pop-inbox-folder)))
 (defun mew-pop-folder-alist ()
@@ -21,7 +23,7 @@
 ;;;
 
 (defvar mew-pop-info-list
-  '("server" "port" "process" "ssh-process" "ssl-process" "status"
+  '("server" "port" "process" "ssh-process" "ssl-process" "ssl-p" "status"
     "directive" "bnm" "mdb"
     "rtrs" "dels" "refs" "rmvs" "kils" "left" "uidl" "range"
     "rttl" "rcnt" "dttl" "dcnt" "hlds"
@@ -41,6 +43,7 @@
 (defvar mew-pop-fsm
   '(("greeting"      nil ("\\+OK" . "capa"))
     ("capa"          t   ("\\+OK" . "auth") ("-ERR" . "pswd"))
+    ("xoauth2"       nil ("\\+OK" . "list") ("-ERR" . "wpwd"))
     ("auth-cram-md5" nil ("\\+OK" . "pwd-cram-md5") ("-ERR" . "wpwd"))
     ("pwd-cram-md5"  nil ("\\+OK" . "list") ("-ERR" . "wpwd"))
     ("auth-plain"    nil ("\\+OK" . "pwd-plain") ("-ERR" . "wpwd"))
@@ -80,7 +83,7 @@
 ;;;
 
 (defun mew-pop-secure-p (pnm)
-  (or (mew-pop-get-ssh-process pnm) (mew-pop-get-ssl-process pnm)))
+  (or (mew-pop-get-ssh-process pnm) (mew-pop-get-ssl-p pnm)))
 
 (defun mew-pop-command-capa (pro pnm)
   (mew-net-status (mew-pop-get-status-buf pnm)
@@ -503,11 +506,19 @@
 
 (defvar mew-pop-auth-alist
   '(("CRAM-MD5" mew-pop-command-auth-cram-md5)
-    ("PLAIN"    mew-pop-command-auth-plain)))
+    ("PLAIN"    mew-pop-command-auth-plain)
+    ("XOAUTH2"  mew-pop-command-auth-xoauth2)))
 
 (defun mew-pop-auth-get-func (auth)
   (nth 1 (mew-assoc-case-equal auth mew-pop-auth-alist 0)))
 
+(defun mew-pop-command-auth-xoauth2 (pro pnm)
+  (let* ((user (mew-pop-get-user pnm))
+	 (tag (mew-pop-passtag pnm))
+         (auth-string (mew-xoauth2-auth-string user tag (mew-pop-get-case pnm))))
+    (mew-pop-process-send-string pro "AUTH XOAUTH2 %s" auth-string)
+    (mew-smtp-set-status pnm "auth-xoauth2")))
+
 (defun mew-pop-command-auth-cram-md5 (pro pnm)
   (mew-pop-process-send-string pro "AUTH CRAM-MD5")
   (mew-pop-set-status pnm "auth-cram-md5"))
@@ -610,14 +621,18 @@
 ;;; Opening POP
 ;;;
 
-(defun mew-pop-open (pnm server port no-msg)
+(defun mew-pop-open (pnm case server port no-msg starttlsp)
   (let ((sprt (mew-*-to-port port))
+	(sslnp (mew-ssl-native-p (mew-pop-ssl case)))
 	pro tm)
     (condition-case emsg
 	(progn
 	  (setq tm (run-at-time mew-pop-timeout-time nil 'mew-pop-timeout))
 	  (or no-msg (message "Connecting to the POP server..."))
-	  (setq pro (open-network-stream pnm nil server sprt))
+	  (setq pro (mew-open-network-stream pnm nil server sprt
+					     'pop sslnp starttlsp case))
+	  (setq pro (car pro))
+	  (when (not (processp pro)) (signal 'quit nil))
 	  (mew-process-silent-exit pro)
 	  (mew-set-process-cs pro mew-cs-text-for-net mew-cs-text-for-net)
 	  (or no-msg (message "Connecting to the POP server...done")))
@@ -631,13 +646,19 @@
     pro))
 
 (defun mew-pop-timeout ()
-  (signal 'quit nil))
+  ;; Do not timeout if the NSM query pane is active.
+  (unless (get-buffer "*Network Security Manager*")
+    (message "POP connection timed out (%d seconds)"
+	     mew-pop-timeout-time)
+    (signal 'quit nil)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Launcher
 ;;;
 
+(defvar mew--gnutls-pop-greeting nil)
+
 (defun mew-pop-retrieve (case directive bnm &rest args)
   ;; in +inbox
   (let* ((server (mew-pop-server case))
@@ -646,6 +667,11 @@
 	 (sshsrv (mew-pop-ssh-server case))
 	 (sslp (mew-pop-ssl case))
 	 (sslport (mew-pop-ssl-port case))
+	 (sslnp (mew-ssl-native-p (mew-pop-ssl case)))
+	 (starttlsp
+	  (mew-ssl-starttls-p (mew-pop-ssl case)
+			     (mew-*-to-string (mew-pop-port case))
+			     (mew-pop-ssl-port case)))
          (proxysrv (mew-pop-proxy-server case))
          (proxyport (mew-pop-proxy-port case))
 	 (pnm (mew-pop-info-name case))
@@ -656,29 +682,32 @@
     (if (mew-pop-get-process pnm)
 	(message "Another POP process is running. Try later")
       (cond
+       (sslnp
+	(let ((serv (if starttlsp port sslport)))
+	  (setq process (mew-pop-open pnm case server serv no-msg starttlsp))))
        (sshsrv
 	(setq sshpro (mew-open-ssh-stream case server port sshsrv))
 	(when sshpro
 	  (setq sshname (process-name sshpro))
 	  (setq lport (mew-ssh-pnm-to-lport sshname))
 	  (when lport
-	    (setq process (mew-pop-open pnm "localhost" lport no-msg)))))
+	    (setq process (mew-pop-open pnm case "localhost" lport no-msg nil)))))
        (sslp
-	(if (mew-port-equal port sslport) (setq tls mew-tls-pop))
+	(when starttlsp (setq tls mew-tls-pop))
 	(setq sslpro (mew-open-ssl-stream case server sslport tls))
 	(when sslpro
 	  (setq sslname (process-name sslpro))
 	  (setq lport (mew-ssl-pnm-to-lport sslname))
 	  (when lport
-	    (setq process (mew-pop-open pnm mew-ssl-localhost lport no-msg)))))
+	    (setq process (mew-pop-open pnm case mew-ssl-localhost lport no-msg nil)))))
        (proxysrv
-	(setq process (mew-pop-open pnm proxysrv proxyport no-msg)))
+	(setq process (mew-pop-open pnm case proxysrv proxyport no-msg nil)))
        (t
-	(setq process (mew-pop-open pnm server port no-msg))))
+	(setq process (mew-pop-open pnm case server port no-msg nil))))
       (if (null process)
 	  (if (eq directive 'exec)
 	      (mew-summary-visible-buffer bnm))
-	(mew-summary-lock process "POPing" (or sshpro sslpro))
+	(mew-summary-lock process "POPing" (or sshpro sslp))
 	(mew-sinfo-set-summary-form (mew-get-summary-form bnm))
 	(mew-sinfo-set-summary-column (mew-get-summary-column bnm))
 	(mew-sinfo-set-unread-mark nil)
@@ -690,6 +719,7 @@
 	(mew-pop-set-process pnm process)
 	(mew-pop-set-ssh-process pnm sshpro)
 	(mew-pop-set-ssl-process pnm sslpro)
+	(mew-pop-set-ssl-p pnm sslp)
 	(mew-pop-set-server pnm server)
 	(mew-pop-set-port pnm port)
 	(mew-pop-set-user pnm user)
@@ -725,7 +755,7 @@
 	  (when virtual
 	    (mew-pop-set-status-buf pnm virtual)
 	    (with-current-buffer virtual
-	      (mew-summary-lock process "POPing" (or sshpro sslpro)))))
+	      (mew-summary-lock process "POPing" (or sshpro sslp)))))
 	 ((eq directive 'scan)
 	  (mew-pop-set-range pnm (nth 0 args))
 	  (mew-pop-set-get-body pnm (nth 1 args))
@@ -743,7 +773,16 @@
 	;;
 	(set-process-sentinel process 'mew-pop-sentinel)
 	(set-process-filter process 'mew-pop-filter)
-	(set-process-buffer process buf)))))
+	(set-process-buffer process buf)
+	(when sslnp
+	  ;; GnuTLS receives POP greeting in its internals
+	  ;; and passes it as a return value.
+	  ;; We store the value in the variable mew--gnutls-pop-greeting
+	  ;; and pass it to the filter to process the greeting.
+	  (mew-pop-filter process
+			  (string-replace "\r\n" "\n"
+					  mew--gnutls-pop-greeting)))
+	))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
