@@ -1,11 +1,16 @@
 ;;; mew-smtp.el
 
-;; Author:  Kazu Yamamoto <Kazu@Mew.org>
+;; Author:  Mew developing team
 ;; Created: Dec  3, 1999
 
 ;;; Code:
 
 (require 'mew)
+(autoload 'puny-encode-domain "puny")
+(when (and (fboundp 'gnutls-available-p)
+	   (gnutls-available-p))
+  (require 'gnutls)
+  (require 'nsm))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -21,7 +26,7 @@
     "server" "port" "ssh-server"
     "user" "auth-user" "auth-list"
     "helo-domain"
-    "status" "process" "ssh-process" "ssl-process"
+    "status" "process" "ssh-process" "ssl-process" "ssl-p"
     "qfld" "messages"
     ;; parameters used internally and should be initialized
     "string" "error" "auth-selected" "timer" "cont" "from" "sender"
@@ -48,6 +53,10 @@
     ("user-login"    ("334" . "pwd-login") (t . "wpwd"))
     ("pwd-login"     ("235" . "next") (t . "wpwd"))
     ("auth-plain"    ("235" . "next") (t . "wpwd"))
+    ;; This is checked only for Gmail https://developers.google.com/gmail/imap/xoauth2-protocol
+    ;; XXX: MS Exchange Returns 334 like CRAM-MD5?
+    ;;  https://docs.microsoft.com/en-us/exchange/client-developer/legacy-protocols/how-to-authenticate-an-imap-pop-smtp-application-by-using-oauth
+    ("auth-xoauth2"  ("235" . "next") (t . "wpwd"))
 ;; See blow
 ;;    ("auth-plain"    ("334" . "pwd-plain") (t . "wpwd"))
 ;;    ("pwd-plain"     ("235" . "next") (t . "wpwd"))
@@ -123,6 +132,7 @@
   (let ((msgs (mew-smtp-get-messages pnm))
 	(qfld (mew-smtp-get-qfld pnm))
 	(case (mew-smtp-get-case pnm))
+	(buf (process-buffer pro))
 	msg)
     (if msgs
 	(progn
@@ -134,6 +144,7 @@
 	  (mew-smtp-set-case pnm case) ;; override
 	  (mew-smtp-set-messages pnm msgs)
 	  (set-process-buffer pro (current-buffer))
+	  (mew-remove-buffer buf)
 	  (mew-smtp-set-status pnm "mail-from")
 	  (mew-smtp-command-mail-from pro pnm))
       (mew-smtp-set-status pnm "quit")
@@ -236,7 +247,7 @@
     (mew-smtp-set-status pnm "quit")
     (mew-smtp-process-send-string pro "QUIT")))
 
-(defun mew-smtp-command-noop (pro pnm)
+(defun mew-smtp-command-noop (_pro _pnm)
   ())
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -247,7 +258,8 @@
 (defvar mew-smtp-auth-alist
   '(("CRAM-MD5" mew-smtp-command-auth-cram-md5)  ;; RFC 2195
     ("PLAIN"    mew-smtp-command-auth-plain)     ;; RFC 2595
-    ("LOGIN"    mew-smtp-command-auth-login)))   ;; No spec
+    ("LOGIN"    mew-smtp-command-auth-login)     ;; No spec
+    ("XOAUTH2"  mew-smtp-command-auth-xoauth2)))
 
 (defun mew-smtp-auth-get-func (auth)
   (nth 1 (mew-assoc-case-equal auth mew-smtp-auth-alist 0)))
@@ -306,6 +318,13 @@
     (mew-smtp-process-send-string pro "AUTH PLAIN %s" plain)
     (mew-smtp-set-status pnm "auth-plain")))
 
+(defun mew-smtp-command-auth-xoauth2 (pro pnm)
+  (let* ((user (mew-smtp-get-auth-user pnm))
+	 (tag (mew-smtp-passtag pnm))
+         (auth-string (mew-xoauth2-auth-string user tag (mew-smtp-get-case pnm))))
+    (mew-smtp-process-send-string pro "AUTH XOAUTH2 %s" auth-string)
+    (mew-smtp-set-status pnm "auth-xoauth2")))
+
 ;; (defun mew-smtp-command-auth-plain (pro pnm)
 ;;   (mew-smtp-process-send-string pro "AUTH PLAIN")
 ;;   (mew-smtp-set-status pnm "auth-plain"))
@@ -384,22 +403,243 @@
 
 (defvar mew-smtp-submission-family 'ipv4)
 
+;;; XXX: (mew-open-network-stream) always returns a list
+;;       and is also used for non-SMTP protocols.
+;;; XXX: port must be resolved by using mew-serv-to-port
+;;       because some service names are not in /etc/services.
+;;       mew-serv-to-port uses mew-port-db.
+(setq mew--advice-tls-parameters-plist nil)
+(defun mew--advice-filter-args-gnutls-negotiate (&rest args)
+  (nconc (car args) mew--advice-tls-parameters-plist))
+;;;
+;;; Functions to handle tunneling by an external program.  The
+;;; external program must be capable of bidirectional communications
+;;; via stdin and stdout and forward the data stream from/to the final
+;;; destination.  TLS and STARTTLS will be handled by GnuTLS.
+;;;
+(defun mew--tun-type (tun-plist)
+  (plist-get tun-plist :type))
+(setq mew--advice-tun-command nil)
+(defun mew--advice-tun-command (case host port tun-plist)
+  (cond
+   ((eq (mew--tun-type tun-plist) 'ssh)
+    (format "%s -W %s:%s -oPort=%s %s"
+	    (mew-ssh-prog case)
+	    (plist-get tun-plist :host)
+	    (plist-get tun-plist :port)
+	    port host))
+   (t nil)))
+;; Override function for TLS connection over tunnel.
+(defun mew--advice-override-open-gnutls-stream
+    (name buffer host service &optional nowait)
+  ;; Must be equivalent to
+  ;; (open-gnutls-stream name buffer host service &optional nowait)
+  (make-process args
+		:command mew--advice-tun-command
+		:coding 'utf-8-unix
+		:connection-type 'pipe
+		:noquery t
+		:stderr nil)
+  ;; Do gnutls-negotiate here
+  )
+;; Override function for PLAIN or STARTTLS connection over tunnel.
+(defun mew--advice-override-make-network-process (&rest args)
+  ;; PLAIN: make-network-process
+  ;; STARTTLS: make-network-process -> gnutls-negotiate
+  (make-process args
+		:command mew--advice-tun-command
+		:coding 'utf-8-unix
+		:connection-type 'pipe
+		:noquery t
+		:stderr nil))
+;;;
+;;; XXX: This conditional can be removed safely.
 (if (fboundp 'make-network-process)
-    (defun mew-open-network-stream (name buf server port)
-      (let (family nowait pro)
-	(when mew-inherit-submission
+    (defun mew-open-network-stream (name buf server port proto sslnp
+					 starttlsp case &optional tun-plist)
+      (let* ((tun-type (mew--tun-type tun-plist))
+	     (mew--advice-tun-command (mew--advice-tun-command
+				       case server port tun-plist))
+	     (status-msg (format "Opening a %s connection %s%s%s..."
+				(if sslnp "TLS" "TCP")
+				(if sslnp "(GnuTLS" "")
+				(if sslnp
+				    (if starttlsp ", STARTTLS)" ")")
+				  "")
+				(if (eq tun-type 'ssh) " over SSH"
+				  "")))
+	     family nowait pro tlsparams)
+	;; SMTP-specific
+	(when (and (eq proto 'smtp) mew-inherit-submission)
 	  (setq family mew-smtp-submission-family)
 	  (setq nowait t))
-	(setq pro (make-network-process :name name :buffer buf
-					:host server :service port
-					:family family :nowait nowait))
-	(if nowait
+	;; TLS does not work for Unix-domain socket for now.
+	(when (and (not sslnp)
+		   (stringp port) (string-match "^/" port))
+	  (setq family 'local)
+	  (setq server 'local))
+	(cond
+	 ;; Both GnuTLS and NSM are mandatory for 'native.
+	 ((and sslnp (or (not (fboundp 'gnutls-available-p))
+			 (not (gnutls-available-p))
+			 (not (fboundp 'gnutls-boot-parameters))
+			 (not (fboundp 'nsm-level))))
+	  (setq pro
+		(list nil
+		      :error t
+		      :status-msg
+		      (concat status-msg
+			      "FAILED (GnuTLS or NSM not available)"))))
+	 ((and sslnp)
+	  (let ((hostname (puny-encode-domain server))
+		;; Note: on Emacs 26.3 and prior GnuTLS always uses
+		;; the system-wide default path first even if
+		;; trustfiles is specified.
+		(trustfiles (mew-ssl-trustfiles case))
+		(nsm-noninteractive nil)
+		(network-security-level network-security-level))
+	    (when (eq (mew-ssl-verify-level case) 0)
+	      ;; Forcibly disable verification.
+	      (setq network-security-level 'low))
+	    (setq tlsparams
+		  (cons 'gnutls-x509pki
+			;; XXX: (gnutls-boot-parameters) returns
+			;; :priority key instead of :priority-string
+			;; while (gnutls-negotiate) accepts
+			;; :priority-string.  To handle this odd
+			;; mismatch, create :priority-string in the
+			;; result of (gnutls-boot-parameters) here.
+			(let ((boot-params
+			       (gnutls-boot-parameters
+				:type 'gnutls-x509pki
+				:keylist (mew-ssl-client-keycert-list case)
+				:trustfiles (mew-ssl-trustfiles case)
+				:priority-string (mew-ssl-algorithm-priority case)
+				:min-prime-bits mew-ssl-min-prime-bits
+				;;
+				;; mew-ssl-verify-error should be nil
+				;; to defer verification to NSM.  Note
+				;; that gnutls-verify-error overrides
+				;; verify-error when it is nil.
+				;; Setting gnutls-verify-error to t is
+				;; also discouraged.
+				;;
+				:verify-error mew-ssl-verify-error
+				:hostname hostname)))
+			  (plist-put boot-params
+				     :priority-string
+				     (plist-get boot-params :priority)))))
+	    ;; debug output: TLS params
+	    (funcall (intern (concat "mew-" (symbol-name proto) "-debug"))
+		     (format "TLS proto=%s, server=%s:%s, starttlsp=%s"
+			     proto hostname port starttlsp)
+		     (format "verify-level=%s, network-security-level=%s, nowait=%s, tlsparams=%s"
+			     (mew-ssl-verify-level case) network-security-level
+			     nowait
+			     (apply #'concat (mapcar (lambda (a) (format "%s " a)) tlsparams))))
+	    (let ((type (if starttlsp 'starttls 'tls)))
+	      (with-temp-message status-msg
+		;; XXX: (open-network-stream) does not pass tlsparams
+		;; to (gnutls-negotiate) to start STARTTLS.  As a
+		;; workaround, add an advice to forcibly append the
+		;; parameters.  This should be fixed in
+		;; (open-network-stream).
+		(setq mew--advice-tls-parameters-plist (cdr tlsparams))
+		(advice-add 'gnutls-negotiate
+			    :filter-args #'mew--advice-filter-args-gnutls-negotiate)
+		;;
+		;; Override key functions when using a tunnel.
+		(cond
+		 ((and mew--advice-tun-command (eq type 'tls))
+		  (advice-add 'open-gnutls-stream
+			      :override #'mew--advice-override-open-gnutls-stream))
+		 (mew--advice-tun-command
+		  (advice-add 'make-network-process
+			      :override #'mew--advice-override-make-network-process)))
+		(setq pro (open-network-stream
+			   name buf server port
+			   :type type
+			   :return-list t
+			   :nowait nowait
+			   :always-query-capabilities
+			   (mew-starttls-get-param proto :always-query-capabilities nil)
+			   :capability-command
+			   (mew-starttls-get-param proto :capability-command t)
+			   :end-of-capability
+			   (mew-starttls-get-param proto :end-of-capability t)
+			   :end-of-command
+			   (mew-starttls-get-param proto :end-of-command t)
+			   :success
+			   (mew-starttls-get-param proto :success t)
+			   :starttls-function
+			   (mew-starttls-get-param proto :starttls-function nil)))
+		(cond
+		 ((and mew--advice-tun-command (eq type 'tls))
+		  (advice-remove 'open-gnutls-stream
+				 #'mew--advice-override-open-gnutls-stream))
+		 (mew--advice-tun-command
+		  (advice-remove 'make-network-process
+				 #'mew--advice-override-make-network-process)))
+		(advice-remove 'gnutls-negotiate
+			       #'mew--advice-filter-args-gnutls-negotiate)
+		;;
+		;; When a validation error occurs, (car pro) will be nil.
+		;;
+		(let ((plainp (eq 'plain (plist-get (cdr pro) :type)))
+		      (greeting (plist-get (cdr pro) :greeting))
+		      (openp  (and (car pro)
+				   (eq 'open (process-status (car pro)))))
+		      ;; Falling back to a plain connection is allowed
+		      ;; only when verify-level < 2.
+		      (needtlsp (and starttlsp
+				     (> (mew-ssl-verify-level case) 1))))
+		  (cond
+		   ((not openp)
+		    (let ((msg (plist-get (cdr pro) :error)))
+		      (setq pro (list nil
+				      :error t
+				      :status-msg
+				      (concat status-msg "FAILED: " msg)))))
+		   ((and plainp needtlsp)
+		    (delete-process (car pro))
+		    (setq pro (list nil
+				    :error t
+				    :status-msg
+				    (concat status-msg "FAILED"))))
+		   (t
+		    (setq pro (list
+			       (car pro)
+			       :error nil))
+		    (cond
+		     ((eq proto 'pop)
+		      (setq mew--gnutls-pop-greeting greeting))
+		     ((eq proto 'imap)
+		      (setq mew--gnutls-imap-greeting greeting))))))))))
+	 (t
+	  (with-temp-message status-msg
+	    (let ((params (list :name name :buffer buf
+				:service port :family family
+				:nowait nowait))
+		  ;; :host will be ignored when family is 'local.
+		  (host (if (not (eq family 'local))
+			    (list :host server))))
+	      (setq pro (list
+			 (apply #'make-network-process (nconc params host))
+			 :greeting nil
+			 :capabilities nil
+			 :type 'plain
+			 :error nil))))))
+	(if (and (eq proto 'smtp) nowait)
 	    (run-at-time mew-smtp-submission-timeout nil 'mew-smtp-submission-timeout pro))
+	(when (plist-get (cdr pro) :error)
+	  (message (plist-get (cdr pro) :status-msg)))
 	pro))
-  (defalias 'mew-open-network-stream 'open-network-stream))
+  (defun mew-open-network-stream (name buf server port proto sslnp starttlsp case)
+    (open-network-stream name buf server port :return-list t)))
 
-(defun mew-smtp-open (pnm server port)
+(defun mew-smtp-open (pnm case server port starttlsp)
   (let ((sprt (mew-*-to-port port))
+	(sslnp (mew-ssl-native-p (mew-smtp-ssl case)))
 	pro tm)
     ;; xxx some OSes do not define "submission", sigh.
     (when (and (stringp sprt) (string= sprt "submission"))
@@ -408,7 +648,15 @@
 	(progn
 	  (setq tm (run-at-time mew-smtp-timeout-time nil 'mew-smtp-timeout))
 	  (message "Connecting to the SMTP server...")
-	  (setq pro (mew-open-network-stream pnm nil server sprt))
+	  (setq pro (mew-open-network-stream pnm nil server sprt
+					     'smtp sslnp starttlsp case))
+	  (when (and sslnp starttlsp)
+	    (mew-smtp-debug "*GREETING*"
+			    (plist-get (cdr pro) :greeting))
+	    (mew-smtp-debug "*CAPABILITIES*"
+			    (plist-get (cdr pro) :capabilities)))
+	  (setq pro (car pro))
+	  (when (not (processp pro)) (signal 'quit nil))
 	  (mew-process-silent-exit pro)
 	  (mew-set-process-cs pro mew-cs-text-for-net mew-cs-text-for-net)
 	  (message "Connecting to the SMTP server...done"))
@@ -422,7 +670,11 @@
     pro))
 
 (defun mew-smtp-timeout ()
-  (signal 'quit nil))
+  ;; Do not timeout if the NSM query pane is active.
+  (unless (get-buffer "*Network Security Manager*")
+    (message "SMTP connection timed out (%d seconds)"
+	     mew-smtp-timeout-time)
+    (signal 'quit nil)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -436,52 +688,65 @@
 	(pnm (mew-smtp-info-name case fallbacked))
 	(sshsrv (mew-smtp-ssh-server case))
 	(sslp (mew-smtp-ssl case))
-	(sslport (mew-smtp-ssl-port case))
+	(sslport (mew-*-to-string (mew-smtp-ssl-port case)))
+	(sslnp (mew-ssl-native-p (mew-smtp-ssl case)))
+	(starttlsp
+	 (mew-ssl-starttls-p (mew-smtp-ssl case)
+			     (mew-*-to-string (mew-smtp-port case))
+			     (mew-smtp-ssl-port case)))
 	mew-inherit-submission
 	process sshname sshpro sslname sslpro lport tlsp tls fallback)
-    (when (and sslp (mew-port-equal port sslport))
+    (cond
+     ((and (not sslnp) sslp starttlsp)
       (setq tlsp t)
       ;; let stunnel know that a wrapper protocol is SMTP
-      (setq tls mew-tls-smtp))
+      (setq tls mew-tls-smtp)))
     ;; a fallback: "submission" -> "smtp"
     ;; mew-smtp-port is "smtp" and mew-use-submission is t on Emacs 22
-    (when (and (or (not sslp) tlsp)
+    (when (and (or (not sslp) starttlsp tlsp)
 	       (not fallbacked)
 	       mew-use-submission
 	       (fboundp 'make-network-process) ;; Emacs 22 or later
 	       (mew-port-equal port "smtp"))
       (setq port "submission")
       (setq fallback t)
-      (unless tlsp
+      (when (and sslp (not sslnp) (not tlsp))
 	;; TLS uses stunnel. So, we should not use non-blocking connect.
 	;; Timeout should be carried out by stunnel.
 	(setq mew-inherit-submission t))
-      (if (mew-port-equal sslport "smtp") (setq sslport "submission")))
+      (if (mew-port-equal sslport "smtp")
+	  (setq sslport "submission")))
     (cond
+     (sslnp
+      (let ((serv (if starttlsp port sslport)))
+	(setq process (mew-smtp-open pnm case server serv starttlsp))))
      (sshsrv
       (setq sshpro (mew-open-ssh-stream case server port sshsrv))
       (when sshpro
 	(setq sshname (process-name sshpro))
 	(setq lport (mew-ssh-pnm-to-lport sshname))
 	(when lport
-	  (setq process (mew-smtp-open pnm "localhost" lport)))))
+	  (setq process (mew-smtp-open pnm case "localhost" lport nil)))))
      (sslp
       (setq sslpro (mew-open-ssl-stream case server sslport tls))
       (when sslpro
 	(setq sslname (process-name sslpro))
 	(setq lport (mew-ssl-pnm-to-lport sslname))
 	(when lport
-	  (setq process (mew-smtp-open pnm mew-ssl-localhost lport)))))
+	  (setq process (mew-smtp-open pnm case mew-ssl-localhost lport nil)))))
      (t
-      (setq process (mew-smtp-open pnm server port))))
+      (setq process (mew-smtp-open pnm case server port nil))))
     (if (null process)
 	(cond
 	 ((and sshsrv (null sshpro))
 	  (message "Cannot create to the SSH connection"))
+	 (sslnp
+	  (message "Cannot open an SSL/TLS (GnuTLS) connection"))
 	 ((and sslp (null sslpro))
 	  (message "Cannot create to the SSL/TLS connection"))
 	 (t
-	  (if (and (or (not sslp) tlsp)
+	  (if (and (not (eq server 'local))
+	           (or (not sslp) tlsp)
 		   (not fallbacked)
 		   mew-use-submission
 		   (fboundp 'make-network-process)
@@ -497,11 +762,14 @@
       (mew-smtp-set-qfld pnm qfld)
       (mew-smtp-set-messages pnm msgs)
       (mew-smtp-set-server pnm server)
-      (mew-smtp-set-port pnm port)
+      (if sslp
+	  (mew-smtp-set-port pnm sslport)
+	(mew-smtp-set-port pnm port))
       (mew-smtp-set-process pnm process)
       (mew-smtp-set-ssh-server pnm sshsrv)
       (mew-smtp-set-ssh-process pnm sshpro)
       (mew-smtp-set-ssl-process pnm sslpro)
+      (mew-smtp-set-ssl-p pnm sslp)
       (mew-smtp-set-helo-domain pnm (mew-smtp-helo-domain case))
       (mew-smtp-set-user pnm user)
       (mew-smtp-set-auth-user pnm (mew-smtp-user case))
@@ -512,7 +780,15 @@
       (set-process-buffer process nil)
       (set-process-sentinel process 'mew-smtp-sentinel)
       (set-process-filter process 'mew-smtp-filter)
-      (message "Sending in background..."))))
+      (message "Sending in background...")
+      ;;
+      (when sslnp
+	;; GnuTLS requires a client-initiated command after the
+	;; session is established or upgraded to use TLS because
+	;; no additional greeting from the server.
+	(mew-smtp-set-status pnm "ehlo")
+	(mew-smtp-command-ehlo process pnm))
+      )))
 
 (defun mew-smtp-flush-queue (case &optional qfld)
   (let (msgs)
@@ -599,7 +875,7 @@
        (t
 	(mew-smtp-sentinel2 process event))))))
 
-(defun mew-smtp-sentinel2 (process event)
+(defun mew-smtp-sentinel2 (process _event)
   (let* ((pnm (process-name process))
 	 (buf (process-buffer process))
 	 (qfld (mew-smtp-get-qfld pnm))
@@ -618,7 +894,10 @@
 	  (set-buffer buf)
 	  (mew-smtp-queue case error pnm))
 	(mew-smtp-log pnm error)
-	(message-box (format "%s  This mail has been queued to %s" error qfld)))
+
+	(if (memq system-type '(windows-nt ms-dos cygwin))
+	    (message (format "%s  This mail has been queued to %s" error qfld))
+	  (message-box (format "%s  This mail has been queued to %s" error qfld))))
        (done
 	(message "Sending in background...done"))
        (t
@@ -727,7 +1006,7 @@
 	(server (mew-smtp-get-server pnm))
 	(port (mew-smtp-get-port pnm))
 	(sshsrv (mew-smtp-get-ssh-server pnm))
-	(sslp (mew-smtp-get-ssl-process pnm)))
+	(sslp (mew-smtp-get-ssl-p pnm)))
     (with-temp-buffer
       (and logtime (insert logtime))
       (and msgid (insert " id=" msgid))
@@ -751,7 +1030,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2015 Mew developing team.
+;; Copyright (C) 1999-2023 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
