@@ -56,7 +56,7 @@
 
 (defun mew-summary-goto-folder (&optional goend)
   "Go to the folder which you specify.  If executed with
-'\\[universal-argument]', the cursor always goes to the bottom of
+`\\[universal-argument]', the cursor always goes to the bottom of
 Summary mode."
   (interactive "P")
   (let* ((proto (mew-proto-to-go (mew-summary-folder-name 'ext)))
@@ -139,7 +139,7 @@ Summary mode."
 
 (defun mew-summary-goto-line (&optional arg)
   "Jump to a line according to the number which you input.
-If 'mew-summary-goto-line-then-display' is non-nil,
+If `mew-summary-goto-line-then-display' is non-nil,
 the message is then displayed."
   (interactive "P")
   (if arg
@@ -220,7 +220,7 @@ the message is then displayed."
 
 (defun mew-summary-jump-top ()
   "Go to the beginning of this Summary mode.
-If 'mew-summary-jump-top-then-display' is non-nil,
+If `mew-summary-jump-top-then-display' is non-nil,
 the top message is then displayed."
   (interactive)
   (if mew-use-push-mark (mew-push-mark))
@@ -230,7 +230,7 @@ the top message is then displayed."
 
 (defun mew-summary-jump-bottom ()
   "Go to the end of this Summary mode.
-If 'mew-summary-jump-bottom-then-display' is non-nil,
+If `mew-summary-jump-bottom-then-display' is non-nil,
 the top message is then displayed."
   (interactive)
   (if mew-use-push-mark (mew-push-mark))
@@ -248,7 +248,7 @@ the top message is then displayed."
 ;;;
 
 (defun mew-summary-exchange-point ()
-  "\\<mew-summary-mode-map>Get back to the position before typing '\\[mew-summary-retrieve]' or '\\[mew-summary-ls]'."
+  "\\<mew-summary-mode-map>Get back to the position before typing `\\[mew-summary-retrieve]' or `\\[mew-summary-ls]'."
   (interactive)
   (mew-summary-only
    (let ((pos (mew-sinfo-get-ret-pos)))
@@ -296,7 +296,7 @@ the top message is then displayed."
 
 (defun mew-summary-pipe-message (prefix command)
   "Send the content of Message buffer to a command via pipe.
-If called with '\\[universal-argument]', the body of the message
+If called with `\\[universal-argument]', the body of the message
 \(excluding its header) is sent."
   (interactive
    (list current-prefix-arg
@@ -320,8 +320,8 @@ If called with '\\[universal-argument]', the body of the message
 ;;;
 
 (defun mew-summary-print (&optional arg)
-  "Print the content of Message mode according to 'mew-print-function'.
-If called with '\\[universal-argument]', you can specify a printer name."
+  "Print the content of Message mode according to `mew-print-function'.
+If called with `\\[universal-argument]', you can specify a printer name."
   (interactive "P")
   (mew-summary-display 'redisplay)
   (let ((printer-name (if arg
@@ -347,7 +347,7 @@ If called with '\\[universal-argument]', you can specify a printer name."
 
 (defun mew-summary-store (&optional askcs)
   "Saving a buffer of Message mode to a file.
-If executed with '\\[universal-argument]', coding-system is asked."
+If executed with `\\[universal-argument]', coding-system is asked."
   (interactive "P")
   (mew-summary-display 'redisplay)
   (let* ((file (mew-summary-input-file-name))
@@ -408,7 +408,7 @@ argument."
 
 (defun mew-summary-cmd-msgs ()
   "Executing an external command specifying messages
-marked with '*' as arguments."
+marked with `*' as arguments."
   (interactive)
   (mew-summary-multi-msgs
    (let* ((cmd-args (mew-input-command))
@@ -445,7 +445,7 @@ marked with '*' as arguments."
 If in +postq, post the messages in +postq.
 If in %queue, process the jobs in %queue.
 Otherwise, flush the default queue.
-If executed with '\\[universal-argument]', you can set the sending case."
+If executed with `\\[universal-argument]', you can set the sending case."
   (interactive "P")
   (if (mew-folder-imap-queuep)
       (progn
@@ -490,10 +490,10 @@ If executed with '\\[universal-argument]', you can set the sending case."
   "\\<mew-summary-mode-map>
 Kill a process in Summary mode.
 Sometime a process accidentally remains in Summary mode.
-In this situation, you cannot execute '\\[mew-summary-retrieve]', '\\[mew-summary-ls]', nor '\\[mew-summary-exec]'.
+In this situation, you cannot execute `\\[mew-summary-retrieve]', `\\[mew-summary-ls]', nor `\\[mew-summary-exec]'.
 Use this command to solve this problem.
 
-If called with '\\[universal-argument]', all SSH processes, if
+If called with `\\[universal-argument]', all SSH processes, if
 any, are killed."
   (interactive "P")
   (let ((process mew-summary-buffer-process)
@@ -535,7 +535,7 @@ any, are killed."
 ;;;
 
 (defun mew-summary-unshar ()
-  "Apply 'unshar' on messages marked with '*'."
+  "Apply `unshar' on messages marked with `*'."
   (interactive)
   (mew-summary-multi-msgs
    (if (y-or-n-p (format "Execute %s for these messages? " mew-prog-unshar))
@@ -545,7 +545,7 @@ any, are killed."
 	 (message "Executing %s...done" mew-prog-unshar)))))
 
 (defun mew-summary-uudecode ()
-  "Apply 'uudecode' on messages marked with '*'."
+  "Apply `uudecode' on messages marked with `*'."
   (interactive)
   (mew-summary-multi-msgs
    (cond
@@ -607,7 +607,7 @@ any, are killed."
 ;;;
 
 (defun mew-summary-join ()
-  "Concat Message/Partial fragments marked with '*' to an original
+  "Concat Message/Partial fragments marked with `*' to an original
 message."
   (interactive)
   (mew-summary-only
@@ -807,8 +807,8 @@ message."
 	 (message "Copied to %s/%s" dstfld dstmsg)))))))
 
 (defun mew-summary-mark-local-copy (&optional arg)
-  "Copy messages marked with '*' to a local folder.  If called
-with '\\[universal-argument]', only messages marked with '*' in
+  "Copy messages marked with `*' to a local folder.  If called
+with `\\[universal-argument]', only messages marked with `*' in
 the region are handled."
  (interactive "P")
   (mew-summary-not-in-draft
@@ -975,9 +975,9 @@ the region are handled."
 ;;;
 
 (defun mew-summary-toggle-disp-msg (&optional arg)
-  "Toggle 'Summary mode only' and 'Summary & Message mode'. If
-you choose 'Summary mode only', you can quickly put the delete
-	marks since the next message is not displayed."
+  "Toggle `Summary mode only' and `Summary & Message mode'. If
+you choose `Summary mode only', you can quickly put the delete
+marks since the next message is not displayed."
   (interactive)
   (cond
    ((eq arg 'on)
@@ -1000,7 +1000,7 @@ you choose 'Summary mode only', you can quickly put the delete
 ;;;
 
 (defun mew-summary-toggle-8bit ()
-  "Toggle 8bit mode(i.e. 'mew-use-8bit')."
+  "Toggle 8bit mode(i.e. `mew-use-8bit')."
   (interactive)
   (setq mew-use-8bit (not mew-use-8bit))
   (if mew-use-8bit
@@ -1025,8 +1025,8 @@ you choose 'Summary mode only', you can quickly put the delete
 
 (defun mew-summary-toggle-warning ()
   "Toggle warning level.
-If 'mew-warning-field-level' is 2, set it to 1.
-If 'mew-warning-field-level' is 1, set it to 2."
+If `mew-warning-field-level' is 2, set it to 1.
+If `mew-warning-field-level' is 1, set it to 2."
   (interactive)
   (if (= mew-warning-field-level 2)
       (setq mew-warning-field-level 1)
@@ -1041,7 +1041,7 @@ If 'mew-warning-field-level' is 1, set it to 2."
 ;;;
 
 (defun mew-summary-toggle-policy (&optional arg)
-  "Toggle decode policy(i.e. 'mew-decode-broken')."
+  "Toggle decode policy(i.e. `mew-decode-broken')."
   (interactive "P")
   (if arg
       (setq mew-decode-broken nil
@@ -1058,7 +1058,7 @@ If 'mew-warning-field-level' is 1, set it to 2."
 ;;;
 
 (defun mew-summary-toggle-debug ()
-  "Toggle 'mew-debug'."
+  "Toggle `mew-debug'."
   (interactive)
   (setq mew-debug (not mew-debug))
   (if mew-debug
@@ -1071,7 +1071,7 @@ If 'mew-warning-field-level' is 1, set it to 2."
 ;;;
 
 (defun mew-summary-toggle-pgp ()
-  "Toggle PGP/MIME and old PGP (i.e. 'mew-use-old-pgp')."
+  "Toggle PGP/MIME and old PGP (i.e. `mew-use-old-pgp')."
   (interactive)
   (setq mew-use-old-pgp (not mew-use-old-pgp))
   (if mew-use-old-pgp
@@ -1085,7 +1085,7 @@ If 'mew-warning-field-level' is 1, set it to 2."
 
 (defun mew-summary-learn-spam ()
   "Learn that this message is a spam.
-See also 'mew-spam-prog' and 'mew-spam-prog-args."
+See also `mew-spam-prog' and `mew-spam-prog-args."
   (interactive)
   (mew-summary-msg
    (let* ((fld (mew-summary-folder-name))
@@ -1109,7 +1109,7 @@ See also 'mew-spam-prog' and 'mew-spam-prog-args."
 
 (defun mew-summary-learn-ham ()
   "Learn that this message is a ham.
-See also 'mew-ham-prog' and 'mew-ham-prog-args."
+See also `mew-ham-prog' and `mew-ham-prog-args."
   (interactive)
   (mew-summary-msg
    (let* ((fld (mew-summary-folder-name))
